@@ -294,10 +294,6 @@ void (*draw) (struct _gamgi_group *);
 int mark;
 
 gamgi_enum type;
-int atom, element, number;
-gamgi_enum structure, filter;
-double visible, coplanar;
-
 double origin[3], center[3];
 double quaternion[4];
 
