@@ -288,15 +288,6 @@ group_new->draw = group->draw;
 group_new->type = group->type;
 group_new->mark = group->mark;
 
-group_new->atom = group->atom;
-group_new->element = group->element;
-group_new->number = group->number;
-
-group_new->structure = group->structure;
-group_new->filter = group->filter;
-group_new->visible = group->visible;
-group_new->coplanar = group->coplanar;
-
 /**************************************
  * copy position and orientation data *
  **************************************/
