@@ -23,15 +23,16 @@ gamgi_dlist *gamgi_engine_filter_atom_element (gamgi_dlist *start,
 int z1, int z2);
 
 gamgi_dlist *gamgi_engine_filter_atom_class (gamgi_dlist *start,
-gamgi_enum class);
+int offset, gamgi_enum class);
 
-gamgi_dlist *gamgi_engine_filter_atom_child (gamgi_dlist *start,
-gamgi_object *parent);
+gamgi_dlist *gamgi_engine_filter_atom_parent (gamgi_dlist *start,
+int offset, gamgi_object *parent);
 
-gamgi_dlist *gamgi_engine_filter_atom_identical (gamgi_dlist *start);
+gamgi_dlist *gamgi_engine_filter_atom_identical (gamgi_dlist *start,
+int offset);
 
-gamgi_dlist *gamgi_engine_filter_atom (gamgi_dlist *dlist,
-gamgi_enum filter, gamgi_enum class, gamgi_object *parent);
+gamgi_dlist *gamgi_engine_filter_atom (gamgi_dlist *start,
+int offset, gamgi_enum filter, gamgi_enum class, gamgi_object *parent);
 
 /*************
  * Rationale *
