@@ -42,8 +42,8 @@ gamgi_text *text_next, *text_before;
  * remove text global selection *
  ********************************/
 
-gamgi_global_selection_clean (&gamgi->texts,
-text->object.selection, "button_text");
+gamgi_global_selection_clean (GAMGI_ENGINE_TEXT,
+&gamgi->texts, "button_text", text->object.selection);
 
 /********************
  * remove text list *
@@ -102,8 +102,8 @@ gamgi_orbital *orbital_next, *orbital_before;
  * remove orbital global selection *
  ***********************************/
 
-gamgi_global_selection_clean (&gamgi->orbitals,
-orbital->object.selection, "button_orbital");
+gamgi_global_selection_clean (GAMGI_ENGINE_ORBITAL,
+&gamgi->orbitals, "button_orbital", orbital->object.selection);
 
 /********************
  * remove text list *
@@ -147,8 +147,8 @@ gamgi_bond *bond_next, *bond_before;
  * remove bond global selection *
  ********************************/
 
-gamgi_global_selection_clean (&gamgi->bonds,
-bond->object.selection, "button_bond");
+gamgi_global_selection_clean (GAMGI_ENGINE_BOND,
+&gamgi->bonds, "button_bond", bond->object.selection);
 
 /********************
  * remove text list *
@@ -200,8 +200,8 @@ gamgi_bond *bond;
  * remove atom global selection *
  ********************************/
 
-gamgi_global_selection_clean (&gamgi->atoms,
-atom->object.selection, "button_atom");
+gamgi_global_selection_clean (GAMGI_ENGINE_ATOM,
+&gamgi->atoms, "button_atom", atom->object.selection);
 
 /********************
  * remove text list *
@@ -263,8 +263,8 @@ gamgi_direction *direction_next, *direction_before;
  * remove direction global selection *
  *************************************/
 
-gamgi_global_selection_clean (&gamgi->directions,
-direction->object.selection, "button_direction");
+gamgi_global_selection_clean (GAMGI_ENGINE_DIRECTION,
+&gamgi->directions, "button_direction", direction->object.selection);
 
 /********************
  * remove text list *
@@ -331,8 +331,8 @@ gamgi_plane *plane_next, *plane_before;
  * remove plane global selection *
  ********************************/
 
-gamgi_global_selection_clean (&gamgi->planes,
-plane->object.selection, "button_plane");
+gamgi_global_selection_clean (GAMGI_ENGINE_PLANE,
+&gamgi->planes, "button_plane", plane->object.selection);
 
 /********************
  * remove text list *
@@ -409,8 +409,8 @@ gamgi_group *group_next, *group_before;
  * remove group global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->groups,
-group->object.selection, "button_group");
+gamgi_global_selection_clean (GAMGI_ENGINE_GROUP,
+&gamgi->groups, "button_group", group->object.selection);
 
 /********************
  * remove text list *
@@ -504,8 +504,8 @@ gamgi_molecule *molecule_next, *molecule_before;
  * remove molecule global selection *
  ************************************/
 
-gamgi_global_selection_clean (&gamgi->molecules,
-molecule->object.selection, "button_molecule");
+gamgi_global_selection_clean (GAMGI_ENGINE_MOLECULE,
+&gamgi->molecules, "button_molecule", molecule->object.selection);
 
 /********************
  * remove text list *
@@ -596,8 +596,8 @@ gamgi_cluster *cluster_next, *cluster_before;
  * remove cluster global selection *
  ***********************************/
 
-gamgi_global_selection_clean (&gamgi->clusters,
-cluster->object.selection, "button_cluster");
+gamgi_global_selection_clean (GAMGI_ENGINE_CLUSTER,
+&gamgi->clusters, "button_cluster", cluster->object.selection);
 
 /********************
  * remove text list *
@@ -717,8 +717,8 @@ gamgi_cell *cell_next, *cell_before;
  * remove cell global selection *
  ********************************/
 
-gamgi_global_selection_clean (&gamgi->cells,
-cell->object.selection, "button_cell");
+gamgi_global_selection_clean (GAMGI_ENGINE_CELL,
+&gamgi->cells, "button_cell", cell->object.selection);
 
 /********************
  * remove text list *
@@ -833,8 +833,8 @@ gamgi_arrow *arrow_next, *arrow_before;
  * remove arrow global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->arrows,
-arrow->object.selection, "button_arrow");
+gamgi_global_selection_clean (GAMGI_ENGINE_ARROW,
+&gamgi->arrows, "button_arrow", arrow->object.selection);
 
 /********************
  * remove text list *
@@ -876,8 +876,8 @@ gamgi_shape *shape_next, *shape_before;
  * remove shape global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->shapes,
-shape->object.selection, "button_shape");
+gamgi_global_selection_clean (GAMGI_ENGINE_SHAPE,
+&gamgi->shapes, "button_shape", shape->object.selection);
 
 /********************
  * remove text list *
@@ -919,8 +919,8 @@ gamgi_graph *graph_next, *graph_before;
  * remove graph global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->graphs,
-graph->object.selection, "button_graph");
+gamgi_global_selection_clean (GAMGI_ENGINE_GRAPH,
+&gamgi->graphs, "button_graph", graph->object.selection);
 
 /********************
  * remove text list *
@@ -963,8 +963,8 @@ gamgi_assembly *assembly_next, *assembly_before;
  * remove assembly global selection *
  ************************************/
 
-gamgi_global_selection_clean (&gamgi->assemblys,
-assembly->object.selection, "button_assembly");
+gamgi_global_selection_clean (GAMGI_ENGINE_ASSEMBLY,
+&gamgi->assemblys, "button_assembly", assembly->object.selection);
 
 /********************
  * remove text list *
@@ -1120,8 +1120,8 @@ gamgi_light *light_next, *light_before;
  * remove light global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->lights,
-light->object.selection, "button_light");
+gamgi_global_selection_clean (GAMGI_ENGINE_LIGHT,
+&gamgi->lights, "button_light", light->object.selection);
 
 /****************
  * remove light *
@@ -1161,8 +1161,8 @@ if (layer->save != NULL) gamgi_gtk_history_layer_reset (layer->save);
  * remove layer global selection *
  *********************************/
 
-gamgi_global_selection_clean (&gamgi->layers,
-layer->object.selection, "button_layer");
+gamgi_global_selection_clean (GAMGI_ENGINE_LAYER,
+&gamgi->layers, "button_layer", layer->object.selection);
 
 /********************
  * remove text list *
@@ -1333,8 +1333,8 @@ if (window->history != NULL)
  * remove window global selection *
  **********************************/
 
-gamgi_global_selection_clean (&gamgi->windows,
-window->object.selection, "button_window");
+gamgi_global_selection_clean (GAMGI_ENGINE_WINDOW,
+&gamgi->windows, "button_window", window->object.selection);
 
 /*********************
  * remove layer list *
