@@ -302,15 +302,9 @@ group->object.number = gamgi_engine_number_group_get ();
  * initialise group *
  ********************/
 
+group->draw = NULL;
+group->type = FALSE;
 group->mark = 0;
-group->atom = -1;
-group->element = -1;
-group->number = 0;
-
-group->structure = FALSE;
-group->filter = FALSE;
-group->visible = 0.0;
-group->coplanar = 0.0;
 
 group->origin[0] = 0.0;
 group->origin[1] = 0.0;
@@ -325,9 +319,6 @@ group->quaternion[1] = 0.0;
 group->quaternion[2] = 0.0;
 group->quaternion[3] = 1.0;
 
-group->draw = NULL;
-group->type = FALSE;
-
 group->points = NULL;
 group->loops = NULL;
 group->n_points = 0;
