@@ -707,17 +707,6 @@ if (direction->type == GAMGI_PHYS_LINE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-/************************
- * thickness (required) *
- ************************/
-
-if (direction->thickness != 0.0 &&
-direction->thickness != GAMGI_CHEM_DIRECTION_THICKNESS)
-  {
-  sprintf (string, "thickness=\"%.*f\"", gamgi->gamgi->length, direction->thickness);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-
 /*****************
  * Position page *
  *****************/
@@ -921,21 +910,6 @@ if (plane->reference == GAMGI_ENGINE_CELL)
 
   }
 
-/****************
- * Polygon page *
- ****************/
-
-/************************
- * thickness (optional) *
- ************************/
-
-if (plane->thickness != 0.0 &&
-plane->thickness != GAMGI_CHEM_PLANE_THICKNESS)
-  {
-  sprintf (string, "thickness=\"%.*f\"", gamgi->gamgi->length, plane->thickness);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-
 /*****************
  * Position page *
  *****************/
