@@ -15,10 +15,21 @@
 
 static gamgi_enum static_class (gamgi_window *window);
 
+static void static_default_layer (gamgi_window *window);
+
+static void static_location (GtkWidget *widget, void *data);
+
 static void static_reset (gamgi_window *window);
 
-static void static_copy (gamgi_atom *atom, gamgi_layer *layer,
-int number, double *shift, gamgi_window *window_dialog);
+static void static_list (GtkWidget *widget, void *data);
+
+static gamgi_bool static_grab (gamgi_window *window);
+
+static gamgi_bool static_apply (gamgi_atom *atom, gamgi_window *window);
+
+static void static_ok_global (gamgi_window *window_dialog);
+
+static void static_ok_local (gamgi_window *window_dialog);
 
 static void static_ok (GtkWidget *widget, void *data);
 
