@@ -534,6 +534,49 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
+static gamgi_dlist *static_ok_length (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_bond *bond;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_bool condition;
+double min, max;
+double dx, dy, dz;
+double length;
+
+/********************
+ * get range limits *
+ ********************/
+
+if (gamgi_gtk_select_entry_double (0.0,
+DBL_MAX, &min, &max, window) == FALSE) return NULL;
+min *= min; max *= max;
+
+/******************************
+ * get list of selected bonds *
+ ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  bond = GAMGI_CAST_BOND dlist->data;
+  
+  dx = bond->atom2->position[0] - bond->atom1->position[0];
+  dy = bond->atom2->position[1] - bond->atom1->position[1];
+  dz = bond->atom2->position[2] - bond->atom1->position[2];
+  length = dx * dx + dy * dy + dz * dz;
+  condition = (length >= min && length <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = bond;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_style (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -839,6 +882,8 @@ else if (strcmp (name, "Order") == 0)
   dlist_new = static_ok_order (dlist_old, action, window);
 else if (strcmp (name, "Covalency") == 0)
   dlist_new = static_ok_covalency (dlist_old, action, window);
+else if (strcmp (name, "Length") == 0)
+  dlist_new = static_ok_length (dlist_old, action, window);
 
 else if (strcmp (name, "Style") == 0)
   dlist_new = static_ok_style (dlist_old, action, window);
@@ -1236,6 +1281,8 @@ gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Order", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Covalency", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Length", -1);
 
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "View", -1);
