@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_phys.h"
 #include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
 
@@ -147,12 +149,9 @@ if (scope == 1)
     { 
     plane = GAMGI_CAST_PLANE dlist->data;
     dlist = dlist->next;
-    if (plane->reference == GAMGI_ENGINE_CELL)
-      { 
-      gamgi_engine_unlink_plane (plane);
-      gamgi_engine_remove_plane (plane);
-      }
-    else plane->autonomy = GAMGI_GTK_ALL;
+    if (plane->type != GAMGI_PHYS_POLYGON)
+      { gamgi_engine_unlink_plane (plane);
+        gamgi_engine_remove_plane (plane); }
     }
   gamgi_engine_reparent_plane (cell->plane_start, parent);
 
@@ -161,12 +160,9 @@ if (scope == 1)
     { 
     direction = GAMGI_CAST_DIRECTION dlist->data;
     dlist = dlist->next;
-    if (direction->reference == GAMGI_ENGINE_CELL)
-      { 
-      gamgi_engine_unlink_direction (direction);
-      gamgi_engine_remove_direction (direction);
-      }
-    else direction->autonomy = GAMGI_GTK_ALL;
+    if (direction->type != GAMGI_PHYS_LINE)
+      { gamgi_engine_unlink_direction (direction);
+        gamgi_engine_remove_direction (direction); }
     }
   gamgi_engine_reparent_direction (cell->direction_start, parent);
 
@@ -426,7 +422,7 @@ if (scope < 2)
  * For all windows: redraw gl_area image *
  *****************************************/
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 }
 
 static void static_ok_local (int scope, gamgi_window *window)
