@@ -513,6 +513,7 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
+GtkWidget *combo;
 
 vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
@@ -544,6 +545,13 @@ if (cell != NULL)
     }
   }
 
+if (cell == NULL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+  }
 }
 
 static void static_reference (GtkWidget *widget, void *data)
@@ -1293,7 +1301,7 @@ if (reference == GAMGI_ENGINE_ATOM)
  * handle node *
  ***************/
 
-if (cache.new[STATIC_O4] == TRUE)
+if (cache.new[STATIC_O4] == TRUE && cache.node[3] != 0)
   {
   if (cell == NULL || gamgi_math_node_check (cell->lattice, cache.node[3]) == FALSE)
     {
