@@ -64,8 +64,7 @@ for (window = gamgi->window_start; window != NULL; window = window->next)
 for (window = gamgi->window_start; window != NULL; window = window->next)
   {
   gamgi_gtk_window_remove_timers (window);
-  gtk_widget_destroy (GTK_WIDGET (window->window));
-  window->window = NULL;
+  gamgi_gtk_window_remove_window (window);
   }
 
 /***********************************************
