@@ -414,4 +414,12 @@ GAMGI_GTK_GAMGI_EXIT, GAMGI_GTK_GAMGI_CONFIG };
 #define GAMGI_GTK_COPY_Y    0.0
 #define GAMGI_GTK_COPY_Z    0.0
 
+/*****************************
+ * defaults for link dialogs *
+ *****************************/
+
+#define GAMGI_GTK_LINK_X    0.0
+#define GAMGI_GTK_LINK_Y    0.0
+#define GAMGI_GTK_LINK_Z    0.0
+
 #endif
