@@ -190,6 +190,7 @@ g_object_unref (style);
 
 void gamgi_gtk_dialog_color_default (GtkWidget *widget, gamgi_window *window)
 {
+GtkWidget *hbox;
 GtkWidget *label;
 GtkStyle *style;
 
@@ -197,7 +198,8 @@ GtkStyle *style;
  * use the default color, taken from the time label *
  ****************************************************/
 
-label = GTK_STATUSBAR (window->statusbar_time)->label;
+hbox = gtk_statusbar_get_message_area (GTK_STATUSBAR (window->statusbar_time));
+label = GTK_WIDGET (gtk_container_get_children (GTK_CONTAINER (hbox))->data);
 style = gtk_style_copy (gtk_widget_get_style (label));
 gtk_widget_set_style (widget, style);
 g_object_unref (style);
