@@ -25,6 +25,7 @@
 #include "gamgi_engine_remove.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_object.h"
+#include "gamgi_gtk_history.h"
 #include "gamgi_mesa_start.h"
 #include "gamgi_chem_geometry.h"
 #include "gamgi_chem_symmetry.h"
@@ -114,10 +115,7 @@ static_reciprocal_start (layer_old, layer);
  * start undo and save mechanisms *
  **********************************/
 
-layer->undo = gamgi_engine_dlist_add_start (NULL);
-layer->save = gamgi_engine_dlist_add_start (NULL);
-layer->undo->data = layer;
-layer->save->data = layer;
+gamgi_gtk_history_start (layer);
 
 return layer;
 }
@@ -240,10 +238,7 @@ strcpy (layer->object.name, "Analysis");
  * start undo and save mechanisms *
  **********************************/
 
-layer->undo = gamgi_engine_dlist_add_start (NULL);
-layer->save = gamgi_engine_dlist_add_start (NULL);
-layer->undo->data = layer;
-layer->save->data = layer;
+gamgi_gtk_history_start (layer);
 
 /****************************************
  * add Voronoi tesselation to new layer *
