@@ -183,7 +183,7 @@ static void static_type (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_scope, *vbox_tolerance, *vbox_view;
+GtkWidget *vbox_scope, *vbox_view;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
@@ -193,7 +193,6 @@ GtkWidget *entry;
  ************/
 
 vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
-vbox_tolerance = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_tolerance");
 vbox_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_view");
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_polytope");
@@ -204,7 +203,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    *****************/
 
   gtk_widget_show (vbox_scope);
-  gtk_widget_show (vbox_tolerance);
   gtk_widget_show (vbox_view);
   label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_central");
   gtk_widget_set_sensitive (label, TRUE);
@@ -225,7 +223,6 @@ else
    ******************/
 
   gtk_widget_hide (vbox_scope);
-  gtk_widget_hide (vbox_tolerance);
   gtk_widget_hide (vbox_view);
   label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_central");
   gtk_widget_set_sensitive (label, FALSE);
@@ -304,12 +301,14 @@ GtkWidget *entry;
 GtkWidget *combo;
 GtkWidget *button;
 gamgi_bool global;
+gamgi_enum structure, filter;
 const char *name;
 char token[GAMGI_ENGINE_TOKEN];
 char string[GAMGI_ENGINE_STRING];
 char line[GAMGI_ENGINE_LINE] = "";
-double radius;
+double visible, coplanar, radius;
 int out[4];
+int number, element;
 
 group->type = GAMGI_CHEM_POLYTOPE;
 
@@ -352,10 +351,10 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
  **********************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
-group->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
-group->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /****************************************************
  *     number of neighbours or maximum radius       *
@@ -364,7 +363,7 @@ group->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
  * all distances and number of neighbours are valid *
  ****************************************************/
 
-group->number = 0;
+number = 0;
 radius = DBL_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
@@ -378,7 +377,7 @@ if (gamgi_io_token_check (name) == TRUE)
      * fixed number of neighbours *
      ******************************/
 
-    if (gamgi_io_token_int_scan (name, &group->number, 2, INT_MAX) == FALSE)
+    if (gamgi_io_token_int_scan (name, &number, 2, INT_MAX) == FALSE)
       {
       gamgi_gtk_dialog_message_create ("Error", 
       "Invalid neighbours number", window);
@@ -404,7 +403,7 @@ if (gamgi_io_token_check (name) == TRUE)
       return;
       }
 
-    group->number = 0;
+    number = 0;
     radius = radius * radius;
     }
   }
@@ -413,14 +412,14 @@ if (gamgi_io_token_check (name) == TRUE)
  * get element for neighbour atoms *
  ***********************************/
 
-group->element = -1;
+element = -1;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
 if (gamgi_io_token_check (name) == TRUE &&
 (gamgi_io_token_alpha_scan (name, token, GAMGI_IO_TEXT,
 GAMGI_ENGINE_TOKEN) == FALSE || gamgi_chem_atom_number (token,
-&group->element) == FALSE))
+&element) == FALSE))
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid neighbours element", window);
   gamgi_engine_remove_group (group);
@@ -433,7 +432,7 @@ GAMGI_ENGINE_TOKEN) == FALSE || gamgi_chem_atom_number (token,
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_visible");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &group->visible,
+if (gamgi_io_token_double_scan (name, &visible,
 0.0, GAMGI_CHEM_POLYTOPE_VISIBLE_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid visible face tolerance", window);
@@ -443,7 +442,7 @@ if (gamgi_io_token_double_scan (name, &group->visible,
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_coplanar");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &group->coplanar,
+if (gamgi_io_token_double_scan (name, &coplanar,
 0.0, GAMGI_CHEM_POLYTOPE_COPLANAR_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid coplanar face tolerance", window);
@@ -504,11 +503,11 @@ else
    * this is undefined, use current color for each central atom   *
    ****************************************************************/
 
-  if (group->element >= 0)
+  if (element >= 0)
     {
-    group->red = gamgi->atom->red[group->element];
-    group->green = gamgi->atom->green[group->element];
-    group->blue = gamgi->atom->blue[group->element];
+    group->red = gamgi->atom->red[element];
+    group->green = gamgi->atom->green[element];
+    group->blue = gamgi->atom->blue[element];
     }
   }
 
@@ -530,16 +529,49 @@ GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
  * global tests *
  ****************/
 
-if (gamgi_engine_find_object (GAMGI_CAST_OBJECT atom, window->focus) == FALSE)
+if (global == TRUE && radius == DBL_MAX)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid searching scope for central atom", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid number selection", window);
   gamgi_engine_remove_group (group);
   return;
   }
 
-if (global == TRUE && radius == DBL_MAX)
+/**********************
+ * check central atom *
+ **********************/
+
+if (gamgi_engine_find_object (GAMGI_CAST_OBJECT atom, window->focus) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid global selection", window);
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid searching scope for central atom", window);
+  gamgi_engine_remove_group (group);
+  return;
+  }
+
+/**********************************
+ * check central atom, neighbours *
+ **********************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT window->layer) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid searching scope for neighbour atoms", window);
+  gamgi_engine_remove_group (group);
+  return;
+  }
+
+/**********************************
+ * check central atom, neighbours *
+ **********************************/
+
+dlist = gamgi_engine_dlist_atom_object (window->focus, NULL);
+dlist = gamgi_engine_filter_atom (dlist, 0, filter,
+GAMGI_ENGINE_GROUP, window->focus);
+if (dlist == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid searching scope for neighbour atoms", window);
   gamgi_engine_remove_group (group);
   return;
   }
@@ -550,14 +582,6 @@ if (global == TRUE && radius == DBL_MAX)
 
 gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
-/*******************************
- * prepare building conditions *
- *******************************/
-
-dlist = gamgi_engine_dlist_atom_object (window->focus, NULL);
-dlist = gamgi_engine_filter_atom (dlist, 0, group->filter,
-GAMGI_ENGINE_GROUP, window->focus);
-
 /***********************************
  * create and initialize text      *
  * widget, to show Polytope report *
@@ -570,8 +594,8 @@ text = gamgi_gtk_dialog_text_create ();
  * number of independent atom positions that were found *
  ********************************************************/
 
-if (gamgi_chem_polytope (dlist, group, atom, global,
-radius, group->structure, out, text) == FALSE)
+if (gamgi_chem_polytope (dlist, group, atom, global, structure,
+visible, coplanar, element, number, radius, out, text) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error",
   "Insufficient number of neighbours", window);
@@ -750,7 +774,7 @@ GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
 GtkWidget *table;
-GtkWidget *hbox_center, *hbox_left;
+GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *combo;
 GtkListStore *store;
@@ -837,6 +861,10 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
+label = gtk_label_new ("Reference");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
 button = gtk_radio_button_new_with_label (NULL, "Container");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
@@ -931,28 +959,32 @@ vbox_top = gtk_vbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/******************************
- * Structure, Filter policies *
- ******************************/
+/*********************
+ * Structure, Filter *
+ *********************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 20);
+hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top_top);
+/**********
+ * column *
+ **********/
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Structure");
-gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "combo_structure", combo);
 gtk_widget_show (combo);
 
@@ -970,16 +1002,20 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top_top);
+/**********
+ * column *
+ **********/
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Filter");
-gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "combo_filter", combo);
 gtk_widget_show (combo);
 
@@ -999,6 +1035,56 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+/*********************
+ * Visible, Coplanar *
+ *********************/
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+hbox_left = gtk_hbox_new (FALSE, 15);
+gtk_box_pack_end (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+/**********
+ * column *
+ **********/
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Visible");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
+g_object_set_data (G_OBJECT (dialog), "entry_visible", entry);
+gtk_widget_show (entry);
+
+/**********
+ * column *
+ **********/
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+label = gtk_label_new ("Coplanar");
+gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
+g_object_set_data (G_OBJECT (dialog), "entry_coplanar", entry);
+gtk_widget_show (entry);
+
 /**************
  * Neighbours *
  **************/
@@ -1007,31 +1093,31 @@ vbox_top_top = gtk_vbox_new (FALSE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top_top);
 
-label = gtk_label_new ("Neighbours");
-gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-table = gtk_table_new (2, 2, FALSE);
+table = gtk_table_new (2, 3, FALSE);
 gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
 gtk_widget_show (table);
 
+label = gtk_label_new ("Neighbours");
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+gtk_widget_show (label);
+
 label = gtk_label_new ("Element");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 10, 5);
+gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 10, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 1, 2, GTK_SHRINK, GTK_FILL, 0, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_SHRINK, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 g_object_set_data (G_OBJECT (dialog), "entry_element", entry);
 gtk_widget_show (entry);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_table_attach (GTK_TABLE (table), hbox_left, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 10, 5);
+gtk_table_attach (GTK_TABLE (table), hbox_left, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 gtk_widget_show (hbox_left);
 
 button = gtk_radio_button_new_with_label (NULL, "Number");
@@ -1049,65 +1135,12 @@ G_CALLBACK (static_number), window);
 gtk_widget_show (button);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_SHRINK, GTK_FILL, 0, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 1, 2, GTK_SHRINK, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
 gtk_widget_show (entry);
 
-/****************************
- * Polytope: Tolerance page *
- ****************************/
-
-vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Tolerance");
-gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
-g_object_set_data (G_OBJECT (dialog), "vbox_tolerance", vbox_page);
-gtk_widget_show (vbox_page);
-
-vbox_center = gtk_vbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
-gtk_widget_show (vbox_center);
-
-/*************************************
- * Face Tolerance: Coplanar, Visible *
- *************************************/
-
-hbox_center = gtk_hbox_new (TRUE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-table = gtk_table_new (2, 3, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
-gtk_widget_show (table);
-
-label = gtk_label_new ("Faces");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_widget_show (label);
-
-label = gtk_label_new ("Visible");
-gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
-gtk_widget_show (label);
-
-entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "entry_visible", entry);
-gtk_widget_show (entry);
-
-label = gtk_label_new ("Coplanar");
-gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
-gtk_widget_show (label);
-
-entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 1, 2, GTK_EXPAND, GTK_FILL, 5, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "entry_coplanar", entry);
-gtk_widget_show (entry);
-
 /***********************
  * Polytope: View page *
  ***********************/
