@@ -121,6 +121,110 @@ if (scope != STATIC_BEFORE && scope != STATIC_CURRENT)
   gamgi_engine_dlist_remove_all (dlist);
 }
 
+static void static_method_autonomy (char *label, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *widget;
+GtkWidget *hbox;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+
+widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
+hbox = gtk_widget_get_parent (widget);
+gtk_widget_destroy (widget);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), label, combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "All", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Partial", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "None", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+}
+
+static void static_method_style (char *label, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *widget;
+GtkWidget *hbox;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+
+widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
+hbox = gtk_widget_get_parent (widget);
+gtk_widget_destroy (widget);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), label, combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Wired", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Solid", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+}
+
+static void static_method_color (char *label, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *widget;
+GtkWidget *hbox;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+
+widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
+hbox = gtk_widget_get_parent (widget);
+gtk_widget_destroy (widget);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), label, combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, " Yes ", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, " No ", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+}
+
 static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -154,10 +258,25 @@ if (gtk_tree_model_iter_has_child (model, &new) == TRUE)
 gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &new);
 gtk_tree_model_get (model, &new, 0, &name, -1);
 
-if (strcmp (name, "Pick") == 0)
+if (strcmp (name, "Pick") == 0 || strcmp (name, "Region") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
+  }
+else if (strcmp (name, "Autonomy") == 0)
+  {
+  static_method_autonomy ("widget_min", window);
+  static_method_autonomy ("widget_max", window);
+  }
+else if (strcmp (name, "Style") == 0)
+  {
+  static_method_style ("widget_min", window);
+  static_method_style ("widget_max", window);
+  }
+else if (strcmp (name, "Color") == 0)
+  {
+  static_method_color ("widget_min", window);
+  static_method_color ("widget_max", window);
   }
 else
   {
@@ -308,6 +427,111 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
+static gamgi_dlist *static_ok_red (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_group *group;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_bool condition;
+float min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+if (gamgi_gtk_select_entry_float (-FLT_MAX,
+FLT_MAX, &min, &max, window) == FALSE) return NULL;
+
+/*******************************
+ * get list of selected groups *
+ *******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  group = GAMGI_CAST_GROUP dlist->data;
+  condition = (group->red >= min && group->red <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = group;
+    }
+  }
+
+return dlist_new;
+}
+
+static gamgi_dlist *static_ok_green (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_group *group;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_bool condition;
+float min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+if (gamgi_gtk_select_entry_float (-FLT_MAX,
+FLT_MAX, &min, &max, window) == FALSE) return NULL;
+
+/*******************************
+ * get list of selected groups *
+ *******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  group = GAMGI_CAST_GROUP dlist->data;
+  condition = (group->green >= min && group->green <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = group;
+    }
+  }
+
+return dlist_new;
+}
+
+static gamgi_dlist *static_ok_blue (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_group *group;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_bool condition;
+float min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+if (gamgi_gtk_select_entry_float (-FLT_MAX,
+FLT_MAX, &min, &max, window) == FALSE) return NULL;
+
+/*******************************
+ * get list of selected groups *
+ *******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  group = GAMGI_CAST_GROUP dlist->data;
+  condition = (group->blue >= min && group->blue <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = group;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_scale (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -409,6 +633,12 @@ else if (strcmp (name, "Group") == 0)
   dlist_new = static_ok_parent (dlist_old,
   action, GAMGI_ENGINE_GROUP, window);
 
+else if (strcmp (name, "R") == 0)
+  dlist_new = static_ok_red (dlist_old, action, window);
+else if (strcmp (name, "G") == 0)
+  dlist_new = static_ok_green (dlist_old, action, window);
+else if (strcmp (name, "B") == 0)
+  dlist_new = static_ok_blue (dlist_old, action, window);
 else if (strcmp (name, "Scale") == 0)
   dlist_new = static_ok_scale (dlist_old, action, window);
 
@@ -453,10 +683,7 @@ else
  * to Current and the model is updated    *
  ******************************************/
 
-if (gamgi->groups == NULL)
-  gamgi_global_selection_hide ("button_group");
-else
-  gamgi_global_selection_show ("button_group");
+gamgi_global_selection_update_windows (&gamgi->groups, "button_group");
 
 static_reset (window);
 }
@@ -825,7 +1052,32 @@ gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Group", -1);
 
 gtk_tree_store_append (tree_store, &iter, NULL);
-gtk_tree_store_set (tree_store, &iter, 0, "Scale", -1);
+gtk_tree_store_set (tree_store, &iter, 0, "Scope", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Central", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Neighbour", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Autonomy", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Number", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Radius", -1);
+
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "View", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Style", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Color", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "R", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "G", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "B", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Scale", -1);
 
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (tree_store));
 g_object_unref (tree_store);
