@@ -201,7 +201,7 @@ switch (window->action)
   case GAMGI_GTK_DIRECTION_CREATE:
   gamgi_gtk_help_dialog_import ("Help Direction Create",  
   "interfaces/direction/create", window, 4, n, "type", 
-  "projection", "line", "view");
+  "projection", "scope", "view");
   break;
 
   case GAMGI_GTK_DIRECTION_COPY:
@@ -222,7 +222,7 @@ switch (window->action)
   case GAMGI_GTK_DIRECTION_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Direction Modify",  
   "interfaces/direction/modify", window, 4, n, "type",
-  "projection", "line", "view");
+  "projection", "scope", "view");
   break;
 
   case GAMGI_GTK_DIRECTION_MEASURE:
@@ -238,7 +238,7 @@ switch (window->action)
   case GAMGI_GTK_PLANE_CREATE:
   gamgi_gtk_help_dialog_import ("Help Plane Create",  
   "interfaces/plane/create", window, 4, n, "type", 
-  "projection", "polygon", "view");
+  "projection", "scope", "view");
   break;
 
   case GAMGI_GTK_PLANE_COPY:
@@ -259,7 +259,7 @@ switch (window->action)
   case GAMGI_GTK_PLANE_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Plane Modify",  
   "interfaces/plane/modify", window, 4, n, "type",
-  "projection", "polygon", "view");
+  "projection", "scope", "view");
   break;
 
   case GAMGI_GTK_PLANE_MEASURE:
