@@ -303,3 +303,9 @@ gtk_widget_show (window->help);
 
 return TRUE;
 }
+
+void gamgi_gtk_help_dialog_tips (GtkWidget *widget, void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Tips",
+"tips", GAMGI_CAST_WINDOW data, 0, 0);
+}
