@@ -631,7 +631,7 @@ static void static_interfaces_plane_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Plane Create", 
 "interfaces/plane/create", data, 4, 1, "type", "projection",
-"polygon", "view");
+"scope", "view");
 }
 
 static void static_interfaces_plane_copy (void *data)
@@ -656,7 +656,7 @@ static void static_interfaces_plane_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Plane Modify",
 "interfaces/plane/modify", data, 4, 1, "type", "projection",
-"polygon", "view");
+"scope", "view");
 }
 
 static void static_interfaces_plane_measure (void *data)
@@ -681,7 +681,7 @@ static void static_interfaces_direction_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Direction Create", 
 "interfaces/direction/create", data, 4, 1, "type", "projection", 
-"line", "view");
+"scope", "view");
 }
 
 static void static_interfaces_direction_copy (void *data)
@@ -706,7 +706,7 @@ static void static_interfaces_direction_modify (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Direction Modify",
 "interfaces/direction/modify", data, 4, 1, "type", "projection", 
-"line", "view");
+"scope", "view");
 }
 
 static void static_interfaces_direction_measure (void *data)
@@ -1215,7 +1215,7 @@ static void static_formats_plane_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Plane Create",
 "formats/plane/create", data, 4, 1, "type", "projection", 
-"polygon", "view");
+"scope", "view");
 }
 
 static void static_formats_direction (void *data)
@@ -1228,7 +1228,7 @@ static void static_formats_direction_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Direction Create",
 "formats/direction/create", data, 4, 1, "type", "projection", 
-"line", "view");
+"scope", "view");
 }
 
 static void static_formats_atom (void *data)
