@@ -154,10 +154,10 @@ if (gtk_tree_model_iter_has_child (model, &new) == TRUE)
 gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &new);
 gtk_tree_model_get (model, &new, 0, &name, -1);
 
-if (strcmp (name, "Pick") == 0)
+if (strcmp (name, "Pick") == 0 || strcmp (name, "Region") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
   }
 else
   {
@@ -447,10 +447,7 @@ else
  * to Current and the model is updated       *
  *********************************************/
 
-if (gamgi->molecules == NULL)
-  gamgi_global_selection_hide ("button_molecule");
-else
-  gamgi_global_selection_show ("button_molecule");
+gamgi_global_selection_update_windows (&gamgi->molecules, "button_molecule");
 
 static_reset (window);
 }
