@@ -21,6 +21,7 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
+#include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
 #include "gamgi_engine_filter.h"
 #include "gamgi_engine_find.h"
@@ -203,7 +204,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_PLANE_VECTORS - 1);
 }
 
 static void static_end_atom (gamgi_window *window)
@@ -325,6 +326,19 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+/**************************
+ * reset atom identifiers *
+ **************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom1");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom2");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom3");
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
 /******************** internal function ****************
@@ -354,7 +368,7 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
-char token[GAMGI_ENGINE_TOKEN];
+char token[GAMGI_ENGINE_TOKEN] = "";
 
 plane->reference = GAMGI_ENGINE_CELL;
 
@@ -377,47 +391,53 @@ if (*cell == NULL)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_h");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &plane->hkl[0], -INT_MAX, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Data", window);
-  gamgi_engine_remove_plane (plane);
-  return FALSE;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &plane->hkl[1], -INT_MAX, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Data", window);
-  gamgi_engine_remove_plane (plane);
-  return FALSE;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_int_scan (name, &plane->hkl[2], -INT_MAX, INT_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Data", window);
-  gamgi_engine_remove_plane (plane);
-  return FALSE;
-  }
-
-if (gamgi_phys_direction_zero (plane->hkl) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &plane->hkl[0], -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid plane indices", window);
   gamgi_engine_remove_plane (plane);
   return FALSE;
   }
 
-/******************
- * get plane name *
- ******************/
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &plane->hkl[1], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid plane indices", window);
+  gamgi_engine_remove_plane (plane);
+  return FALSE;
+  }
 
-sprintf (token, "(%d.%d.%d)", plane->hkl[0], plane->hkl[1], plane->hkl[2]);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_io_token_int_scan (name, &plane->hkl[2], -INT_MAX, INT_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid plane indices", window);
+  gamgi_engine_remove_plane (plane);
+  return FALSE;
+  }
+
+if (gtk_widget_is_sensitive (entry) == TRUE &&
+gamgi_phys_direction_zero (plane->hkl) == TRUE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid plane indices", window);
+  gamgi_engine_remove_plane (plane);
+  return FALSE;
+  }
+
+/*****************************************
+ * get plane name (automatic hkl indices *
+ * are handled later, when generated)    *
+ *****************************************/
+
+if (gtk_widget_is_sensitive (entry) == TRUE)
+  sprintf (token, "(%d.%d.%d)", plane->hkl[0], plane->hkl[1], plane->hkl[2]);
 if (gamgi_gtk_object_name (dialog, "entry_plane",
 token, plane->object.name) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Name", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid plane name", window);
   gamgi_engine_remove_plane (plane);
   return FALSE;
   }
@@ -498,8 +518,9 @@ if (gamgi_phys_plane_polygon (*atom1, *atom2, *atom3) == FALSE)
 return TRUE;
 }
 
-static gamgi_bool static_ok_scope (gamgi_plane *plane, 
-gamgi_cell *cell, int *start, int *end, gamgi_window *window)
+static gamgi_bool static_ok_scope (gamgi_plane *plane, gamgi_cell *cell,
+double *thickness, gamgi_enum *structure, gamgi_enum *filter, int *start,
+int *end, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
@@ -512,10 +533,10 @@ int o1, o2, o3;
  **********************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
-plane->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+*structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
-plane->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+*filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -523,7 +544,7 @@ plane->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &plane->thickness, 
+if (gamgi_io_token_double_scan (name, thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Thickness Data", window);
@@ -700,8 +721,10 @@ gamgi_object *parent;
 gamgi_dlist *dlist;
 GtkWidget *button;
 double zero[3];
+double thickness;
 int start, end;
 gamgi_enum pole, trace;
+gamgi_enum structure, filter;
 
 plane = gamgi_engine_create_plane ();
 gamgi_engine_start_plane (plane);
@@ -732,7 +755,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     }
   else
     {
-    if (static_ok_scope (plane, cell, &start, &end, window) == FALSE) return;
+    if (static_ok_scope (plane, cell, &thickness, &structure,
+    &filter, &start, &end, window) == FALSE) return;
     }
   }
 else
@@ -741,8 +765,10 @@ else
    * this is an atomic plane *
    ***************************/
 
-  if (static_ok_atoms (plane, &atom1, &atom2, &atom3, window) == FALSE) return;
-  if (static_ok_scope (plane, NULL, &start, &end, window) == FALSE) return;
+  if (static_ok_atoms (plane, &atom1, &atom2,
+  &atom3, window) == FALSE) return;
+  if (static_ok_scope (plane, NULL, &thickness, &structure,
+  &filter, &start, &end, window) == FALSE) return;
   }
 if (static_ok_view (plane, window) == FALSE) return;
 
@@ -763,10 +789,20 @@ if (plane->reference == GAMGI_ENGINE_CELL)
    * this is a crystallographic plane *
    ************************************/
 
-  if (cell->type == GAMGI_PHYS_PROJECTION)
-    gamgi_phys_plane_projection (plane, cell, pole, trace);
-  else
-    gamgi_phys_plane_range (plane, cell, start, end);
+  dlist = NULL;
+  if (cell->type != GAMGI_PHYS_PROJECTION)
+    {
+    dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+    dlist = gamgi_engine_filter_atom (dlist, 0, filter,
+    GAMGI_ENGINE_PLANE, GAMGI_CAST_OBJECT cell);
+    }
+
+  gamgi_gtk_plane_list_create (plane, cell, structure,
+  filter, thickness, dlist, start, end, pole, trace);
+
+  while (dlist != NULL)
+    dlist = gamgi_engine_dlist_remove_start (dlist);
+  gamgi_engine_remove_plane (plane);
   }
 
 if (plane->reference == GAMGI_ENGINE_ATOM)
@@ -778,12 +814,14 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
    * the plane type is needed because of the rotation next  *
    **********************************************************/
 
+  plane->type = GAMGI_PHYS_POLYGON;
+  plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
+
   parent = gamgi_phys_plane_parent (atom1, atom2, atom3, window);
   dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-  dlist = gamgi_engine_filter_atom (dlist, plane->filter,
-  GAMGI_ENGINE_PLANE, parent);
   dlist = gamgi_phys_plane_reorder (dlist, atom1, atom2, atom3);
-  plane->type = GAMGI_PHYS_POLYGON;
+  dlist = gamgi_engine_filter_atom (dlist, filter, 3, GAMGI_ENGINE_PLANE, parent);
+  if (parent->class <= GAMGI_ENGINE_PLANE) parent = GAMGI_CAST_OBJECT window->layer;
 
   /*********************************************************
    * reset and build plane polygon AFTER linking to parent *
@@ -795,8 +833,8 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
   gamgi_math_position_plane_rotation_set (plane, zero);
   gamgi_math_position_plane_translation_set (plane, zero);
 
-  gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist);
-  plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
+  gamgi_phys_plane_atoms (plane, atom1,
+  atom2, atom3, dlist, structure, thickness);
   }
 
 /************************   
@@ -833,7 +871,7 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
  *********************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_PLANE_VECTORS - 1);
 static_cell (NULL, window);
 
 /************************************
@@ -856,11 +894,12 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-/******************************************
- * initialize data in second level dialog *
- ******************************************/
+/*******************************************
+ * initialize data in second level dialogs *
+ *******************************************/
 
 gamgi_gtk_plane_node_start (window);
+gamgi_gtk_plane_list_start (window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -918,7 +957,7 @@ else
   GAMGI_ENGINE_ATOM, FALSE, static_press);
 }
 
-void gamgi_gtk_plane_create_range (gamgi_bool range, gamgi_window *window)
+void gamgi_gtk_plane_create_range (gamgi_bool active, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button_start, *button_end;
@@ -944,7 +983,7 @@ gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_end), FALSE);
  * enable when Cell and Range are chosen *
  *****************************************/
 
-if (range == TRUE)
+if (active == TRUE)
   {
   gtk_widget_set_sensitive (button_start, TRUE);
   gtk_widget_set_sensitive (button_end, TRUE);
@@ -970,6 +1009,48 @@ else
   }
 }
 
+void gamgi_gtk_plane_create_hkl (gamgi_bool active, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry_h, *entry_k, *entry_l;
+GtkWidget *label_h, *label_k, *label_l;
+
+entry_h = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_h");
+entry_k = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k");
+entry_l = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
+label_h = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_h");
+label_k = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_k");
+label_l = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_l");
+
+/**********************************************************
+ * enable when one hkl plane family is directly specified *
+ **********************************************************/
+
+if (active == TRUE)
+  {
+  gtk_widget_set_sensitive (entry_h, TRUE);
+  gtk_widget_set_sensitive (entry_k, TRUE);
+  gtk_widget_set_sensitive (entry_l, TRUE);
+  gtk_widget_set_sensitive (label_h, TRUE);
+  gtk_widget_set_sensitive (label_k, TRUE);
+  gtk_widget_set_sensitive (label_l, TRUE);
+  }
+else
+  {
+  gtk_entry_set_text (GTK_ENTRY (entry_h), "");
+  gtk_entry_set_text (GTK_ENTRY (entry_k), "");
+  gtk_entry_set_text (GTK_ENTRY (entry_l), "");
+
+  gtk_widget_set_sensitive (entry_h, FALSE);
+  gtk_widget_set_sensitive (entry_k, FALSE);
+  gtk_widget_set_sensitive (entry_l, FALSE);
+  gtk_widget_set_sensitive (label_h, FALSE);
+  gtk_widget_set_sensitive (label_k, FALSE);
+  gtk_widget_set_sensitive (label_l, FALSE);
+  }
+  
+}
+
 /*************** external function ******************
  *                                                  *
  *            GAMGI_GTK_PLANE_CREATE                *
@@ -1001,6 +1082,8 @@ GtkTreeIter iter;
 dialog = gamgi_gtk_dialog_task0_create ("Plane Create", window);
 window->action = GAMGI_GTK_PLANE_CREATE;
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+g_signal_connect (dialog, "destroy",
+G_CALLBACK (gamgi_gtk_plane_list_destroy), window);
 
 /********************
  * global container *
@@ -1141,14 +1224,17 @@ gtk_widget_show (table);
 
 label = gtk_label_new ("H");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_h", label);
 gtk_widget_show (label);
 
 label = gtk_label_new ("K");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_k", label);
 gtk_widget_show (label);
 
 label = gtk_label_new ("L");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_EXPAND, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_l", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -1182,7 +1268,7 @@ button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_plane_list), window);
-g_object_set_data (G_OBJECT (dialog), "button_set", button);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /***********************
@@ -1417,7 +1503,7 @@ store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Class", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_set (store, &iter, 0, "Parent", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
