@@ -560,6 +560,7 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *vbox_scope, *vbox_position, *vbox_projection;
+GtkWidget *combo;
 
 vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_position = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
@@ -597,6 +598,13 @@ if (cell != NULL)
     }
   }
 
+if (cell == NULL)
+  {
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_LOCAL);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_LOCAL);
+  }
 }
 
 static void static_reference (GtkWidget *widget, void *data)
@@ -1268,7 +1276,7 @@ if (reference == GAMGI_ENGINE_CELL)
     }
 
   if ((type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE) &&
-  (projection == NULL || cell->type != GAMGI_PHYS_PROJECTION))
+  (projection == NULL || cell == NULL || cell->type != GAMGI_PHYS_PROJECTION))
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
