@@ -15,6 +15,8 @@
 
 static gamgi_enum static_class (gamgi_window *window);
 
+static void static_reference (GtkWidget *widget, void *data);
+
 static void static_hierarchy (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
@@ -23,8 +25,16 @@ static void static_clean (gamgi_window *window);
 
 static void static_list (GtkWidget *widget, void *data);
 
-static void static_object (gamgi_text *text,
-gamgi_object *object, gamgi_window *window);
+static void static_origin (gamgi_object *child, gamgi_object *parent);
+
+static gamgi_bool static_grab (gamgi_window *window);
+
+static gamgi_bool static_apply (gamgi_object *child, gamgi_object *parent,
+gamgi_layer *layer_child, gamgi_layer *layer_parent, gamgi_window *window);
+
+static void static_ok_global (gamgi_window *window_dialog);
+
+static void static_ok_local (gamgi_window *window_dialog);
 
 static void static_ok (GtkWidget *widget, void *data);
 
