@@ -35,6 +35,7 @@
 #include "gamgi_gtk_help_topic.h"
 #include "gamgi_gtk_help_search.h"
 #include "gamgi_gtk_help_tutorial.h"
+#include "gamgi_gtk_help_dialog.h"
 #include "gamgi_gtk_help_start.h"
 #include "gamgi_gtk_text_copy.h"
 #include "gamgi_gtk_text_config.h"
@@ -1188,6 +1189,7 @@ static_item_insert (menu, "Current", NULL, gamgi_gtk_help_current, window);
 static_item_insert (menu, "Topic", NULL, gamgi_gtk_help_topic, window);
 static_item_insert (menu, "Search", NULL, gamgi_gtk_help_search, window);
 static_item_insert (menu, "Tutorial", NULL, gamgi_gtk_help_tutorial, window);
+static_item_insert (menu, "Tips", NULL, gamgi_gtk_help_dialog_tips, window);
 /*
 static_item_insert (menu, "Progress", NULL, gamgi_gtk_statusbar_mode, window);
 */
