@@ -523,8 +523,7 @@ double axis[3];
 double phi;
 float color[3];
 
-if (direction->autonomy != GAMGI_GTK_NONE)
-  static_scale (fp, direction->object.scale, direction->center, error);
+static_scale (fp, direction->object.scale, direction->center, error);
 	
 if (direction->loops[0] != 0)
   {
@@ -619,7 +618,7 @@ for (dlist = direction->orbital_start; dlist != NULL; dlist = dlist->next)
 for (dlist = direction->text_start; dlist != NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
 	
-if (direction->autonomy != GAMGI_GTK_NONE && direction->loops[0]!=0)
+if (direction->loops[0] != 0)
   static_unscale (fp, direction->object.scale, error);
 }
 
@@ -632,12 +631,22 @@ double axis[3];
 double phi;
 float color[3];
 
-if (plane->autonomy != GAMGI_GTK_NONE)
-  static_scale (fp, plane->object.scale, plane->center, error);
-	
+static_scale (fp, plane->object.scale, plane->center, error);
+
 if (plane->loops[0] != 0)
   {
-  if (plane->reciprocal == 0.0)
+  if (plane->type == GAMGI_PHYS_VECTOR)
+    {
+    /*******************************************************
+     * reciprocal lattice: render plane as a cross bitmask *
+     *******************************************************/
+
+    color[0] = plane->red;
+    color[1] = plane->green;
+    color[2] = plane->blue;
+    gamgi_io_x3d_render_cross (fp, plane->loops[0], plane->points, color, error);
+    }
+  else
     {
     sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\">\n", 
     gamgi->gamgi->length, plane->origin[0],
@@ -719,17 +728,6 @@ if (plane->loops[0] != 0)
 			
     gamgi_io_file_fprintf (fp, "</Transform>\n", error);
     }
-  else
-    {
-    /*******************************************************
-     * reciprocal lattice: render plane as a cross bitmask *
-     *******************************************************/
-
-    color[0] = plane->red;
-    color[1] = plane->green;
-    color[2] = plane->blue;
-    gamgi_io_x3d_render_cross (fp, plane->loops[0], plane->points, color, error);
-    }
   }
 	
 /*************************************************
@@ -748,7 +746,7 @@ for (dlist = plane->orbital_start; dlist != NULL; dlist = dlist->next)
 for (dlist = plane->text_start; dlist != NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
 
-if (plane->autonomy != GAMGI_GTK_NONE && plane->loops[0] != 0)
+if (plane->loops[0] != 0)
   static_unscale (fp, plane->object.scale, error);
 }
 
