@@ -80,7 +80,8 @@ GAMGI_MATH_POLYTOPE_3, GAMGI_MATH_POLYTOPE_4 };
  ******************************************/
 
 #define GAMGI_MATH_DIRECTION_LENGTH 0.1
-#define GAMGI_MATH_PLANE_AREA       0.1
+#define GAMGI_MATH_DIRECTION_AREA   0.1
+#define GAMGI_MATH_PLANE_AREA    1.0E-4
 
 /**********************************************
  * minimum length of the cross product of two *
