@@ -17,6 +17,8 @@
 #include "gamgi_math_vector.h"
 #include "gamgi_math_position.h"
 #include "gamgi_math_cell.h"
+#include "gamgi_math_node.h"
+#include "gamgi_math_polygon.h"
 #include "gamgi_phys_cell.h"
 #include "gamgi_phys_plane.h"
 #include "gamgi_phys_direction.h"
@@ -183,6 +185,7 @@ gamgi_bool gamgi_math_measure_length_atom_direction (gamgi_atom *atom,
 gamgi_direction *direction, double *length)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], normal[3];
 double translate[3];
 double r1[3], r2[3];
@@ -223,8 +226,9 @@ else
    * passing through the cell origin    *
    **************************************/
 
-  if (direction->reference != GAMGI_ENGINE_CELL) return FALSE;
-  cell = GAMGI_CAST_CELL direction->object.object;
+  object = GAMGI_CAST_OBJECT direction->object.object;
+  if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+  cell = GAMGI_CAST_CELL object;
 
   gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, pole);
   gamgi_math_cell_vector_rotate (cell, pole, normal);
@@ -246,6 +250,7 @@ gamgi_bool gamgi_math_measure_length_atom_plane (gamgi_atom *atom,
 gamgi_plane *plane, double *length)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], normal[3];
 double translate[3], origin[3];
 double r1[3];
@@ -280,14 +285,11 @@ else
    * or projection): the parent must be a cell   *
    ***********************************************/
 
-  if (plane->reference != GAMGI_ENGINE_CELL) return FALSE;
-  cell = GAMGI_CAST_CELL plane->object.object;
+  object = GAMGI_CAST_OBJECT plane->object.object;
+  if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+  cell = GAMGI_CAST_CELL object;
 
-  /********************
-   * reciprocal space *
-   ********************/
-
-  if (plane->reciprocal != 0)
+  if (plane->type == GAMGI_PHYS_VECTOR)
     {
     /********************
      * reciprocal space *
@@ -299,10 +301,10 @@ else
     }
   else
     {
-    /***********************************
-     * projected planes: use plane     *
-     * passing through the cell origin *
-     ***********************************/
+    /***************************************
+     * stereographic projection: use plane *
+     * passing through the cell origin     *
+     ***************************************/
 
     gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, pole);
     gamgi_math_cell_vector_rotate (cell, pole, normal);
@@ -316,12 +318,23 @@ else
 return TRUE;
 }
 
-gamgi_bool gamgi_math_measure_length_direction (gamgi_direction *direction, 
+gamgi_bool gamgi_math_measure_length_direction (gamgi_direction *direction, double *length)
+{
+if (direction->type != GAMGI_PHYS_LINE) return FALSE;
+
+*length = gamgi_math_polygon_length_lines (direction->loops, direction->points);
+
+return TRUE;
+}
+
+gamgi_bool gamgi_math_measure_length_node_direction (gamgi_direction *direction, 
 double *length)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3];
-int uvw_min[3];
+int *uvw;
+int node[3], node_min[3];
 
 /*******************************************
  *   the parent of a crystallographic      *
@@ -330,11 +343,18 @@ int uvw_min[3];
  *        rotate no, normalize no          *
  *******************************************/
 
-if (direction->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL direction->object.object;
+object = GAMGI_CAST_OBJECT direction->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
 
-gamgi_phys_direction_decrease (direction->uvw, uvw_min);
-gamgi_phys_direction_vector (cell, uvw_min, direction->vectors, pole);
+uvw = direction->uvw;
+if (direction->vectors == GAMGI_PHYS_CONVENTIONAL)
+  gamgi_math_node_primitive (cell->lattice,
+  uvw[0], uvw[1], uvw[2], FALSE, &node[0], &node[1], &node[2]);
+else { node[0] = uvw[0]; node[1] = uvw[1]; node[2] = uvw[2]; }
+
+gamgi_phys_direction_decrease (node, node_min);
+gamgi_phys_direction_vector (cell, node_min, GAMGI_PHYS_PRIMITIVE, pole);
 *length = gamgi_math_vector_length (pole);
 
 return TRUE;
@@ -348,9 +368,11 @@ return TRUE;
  *                                    *
  **************************************/
 
-gamgi_bool gamgi_math_measure_length_plane (gamgi_plane *plane, double *length)
+gamgi_bool gamgi_math_measure_length_plane (gamgi_plane *plane,
+double *length)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], origin[3];
 
 /******************************************
@@ -367,35 +389,47 @@ double pole[3], origin[3];
  *       rotate no, normalize no          *
  ******************************************/
 
-if (plane->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL plane->object.object;
+object = GAMGI_CAST_OBJECT plane->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
 
-if (plane->reciprocal == 0)
+if (plane->type == GAMGI_PHYS_VECTOR)
+  {
+  if (cell->reciprocal == 0.0) return FALSE;
+  gamgi_math_cell_offset (cell, origin);
+  gamgi_math_vector_sub (plane->points, origin, pole);
+  *length = cell->reciprocal / gamgi_math_vector_length (pole);
+  }
+else
   {
   gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, pole);
   *length = 1.0 / gamgi_math_vector_length (pole);
   }
-else
-  {
-  gamgi_math_cell_offset (cell, origin);
-  gamgi_math_vector_sub (plane->points, origin, pole);
-  *length = plane->reciprocal / gamgi_math_vector_length (pole);
-  }
+
+return TRUE;
+}
+
+gamgi_bool gamgi_math_measure_area_plane (gamgi_plane *plane, double *area)
+{
+if (plane->type != GAMGI_PHYS_POLYGON) return FALSE;
+
+*area = gamgi_math_polygon_area_faces (plane->loops, plane->points);
 
 return TRUE;
 }
 
 /*********** external function *********
  *                                     *
- *     GAMGI_MATH_MEASURE_AREA_PLANE   *
+ *  GAMGI_MATH_MEASURE_AREA_NODE_PLANE *
  *                                     *
  *  Return area per node in planes hkl *
  *                                     *
  ***************************************/
 
-gamgi_bool gamgi_math_measure_area_plane (gamgi_plane *plane, double *area)
+gamgi_bool gamgi_math_measure_area_node_plane (gamgi_plane *plane, double *area)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double pole[3], origin[3];
 double volume;
 int hkl_min[3], hkl_miller[3];
@@ -406,8 +440,9 @@ gamgi_enum lattice_new;
  * plane or direction must be a cell. *
  **************************************/
 
-if (plane->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL plane->object.object;
+object = GAMGI_CAST_OBJECT plane->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
 
 /*************************************************
  * Planes with indices above the Miller indices  *
@@ -417,13 +452,14 @@ cell = GAMGI_CAST_CELL plane->object.object;
  *************************************************/
 
 gamgi_phys_direction_decrease (plane->hkl, hkl_min);
-if (plane->reciprocal == 0)
-  gamgi_phys_plane_increase (cell->lattice, hkl_min, plane->vectors, hkl_miller);
-else
+if (plane->type == GAMGI_PHYS_VECTOR)
   {
+  if (cell->reciprocal == 0.0) return FALSE;
   lattice_new = gamgi_phys_reciprocal_lattice (cell->lattice);
   gamgi_phys_plane_increase (lattice_new, hkl_min, plane->vectors, hkl_miller);
   }
+else gamgi_phys_plane_increase (cell->lattice, hkl_min, plane->vectors, hkl_miller);
+
 if (gamgi_phys_direction_higher (plane->hkl, hkl_miller) == TRUE) return FALSE;
 
 /*************************************************
@@ -441,16 +477,15 @@ if (gamgi_phys_direction_higher (plane->hkl, hkl_miller) == TRUE) return FALSE;
  *************************************************/
 
 volume = gamgi_math_vector_mix (cell->p1, cell->p2, cell->p3);
-if (plane->reciprocal == 0)
+
+if (plane->type == GAMGI_PHYS_VECTOR)
   {
-  gamgi_phys_plane_vector (cell, hkl_miller, plane->vectors, pole);
-  }
-else
-  {
-  volume = pow (plane->reciprocal, 2) / volume;
+  volume = pow (cell->reciprocal, 2) / volume;
   gamgi_math_cell_offset (cell, origin);
   gamgi_math_vector_sub (plane->points, origin, pole);
   }
+else gamgi_phys_plane_vector (cell, hkl_miller, plane->vectors, pole);
+
 *area = volume * gamgi_math_vector_length (pole);
 
 return TRUE;
@@ -579,6 +614,7 @@ gamgi_bool gamgi_math_measure_angle_2direction (gamgi_direction *direction1,
 gamgi_direction *direction2, double *angle)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double normal1[3], normal2[3];
 double pole[3];
 
@@ -600,8 +636,10 @@ double pole[3];
  * direction1 *
  **************/
 
-if (direction1->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL direction1->object.object;
+object = GAMGI_CAST_OBJECT direction1->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
 gamgi_phys_direction_vector (cell, direction1->uvw, direction1->vectors, pole);
 gamgi_math_cell_vector_rotate (cell, pole, normal1);
 
@@ -609,8 +647,10 @@ gamgi_math_cell_vector_rotate (cell, pole, normal1);
  * direction2 *
  **************/
 
-if (direction2->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL direction2->object.object;
+object = GAMGI_CAST_OBJECT direction2->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
 gamgi_phys_direction_vector (cell, direction2->uvw, direction2->vectors, pole);
 gamgi_math_cell_vector_rotate (cell, pole, normal2);
 
@@ -623,6 +663,7 @@ gamgi_bool gamgi_math_measure_angle_2plane (gamgi_plane *plane1,
 gamgi_plane *plane2, double *angle)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double normal1[3], normal2[3];
 double pole[3], origin[3];
 
@@ -644,34 +685,34 @@ double pole[3], origin[3];
  * plane 1 *
  ***********/
 
-if (plane1->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL plane1->object.object;
-if (plane1->reciprocal == 0)
-  {
-  gamgi_phys_plane_vector (cell, plane1->hkl, plane1->vectors, pole);
-  }
-else
+object = GAMGI_CAST_OBJECT plane1->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
+if (plane1->type == GAMGI_PHYS_VECTOR)
   {
   gamgi_math_cell_offset (cell, origin);
   gamgi_math_vector_sub (plane1->points, origin, pole);
   }
+else gamgi_phys_plane_vector (cell, plane1->hkl, plane1->vectors, pole);
+
 gamgi_math_cell_vector_rotate (cell, pole, normal1);
 
 /***********
  * plane 2 *
  ***********/
 
-if (plane2->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL plane2->object.object;
-if (plane2->reciprocal == 0)
-  {
-  gamgi_phys_plane_vector (cell, plane2->hkl, plane2->vectors, pole);
-  }
-else
+object = GAMGI_CAST_OBJECT plane2->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
+if (plane2->type == GAMGI_PHYS_VECTOR)
   {
   gamgi_math_cell_offset (cell, origin);
   gamgi_math_vector_sub (plane2->points, origin, pole);
   }
+else gamgi_phys_plane_vector (cell, plane2->hkl, plane2->vectors, pole);
+
 gamgi_math_cell_vector_rotate (cell, pole, normal2);
 
 *angle = gamgi_math_vector_angle (normal1, normal2);
@@ -683,6 +724,7 @@ gamgi_bool gamgi_math_measure_angle_plane_direction (gamgi_plane *plane,
 gamgi_direction *direction, double *angle)
 {
 gamgi_cell *cell;
+gamgi_object *object;
 double normal1[3], normal2[3];
 double pole[3], origin[3];
 
@@ -704,25 +746,27 @@ double pole[3], origin[3];
  * plane *
  *********/
 
-if (plane->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL plane->object.object;
-if (plane->reciprocal == 0)
-  {
-  gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, pole);
-  }
-else
+object = GAMGI_CAST_OBJECT plane->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
+if (plane->type == GAMGI_PHYS_VECTOR)
   {
   gamgi_math_cell_offset (cell, origin);
   gamgi_math_vector_sub (plane->points, origin, pole);
   }
+else gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, pole);
+
 gamgi_math_cell_vector_rotate (cell, pole, normal1);
 
 /*************
  * direction *
  *************/
 
-if (direction->reference != GAMGI_ENGINE_CELL) return FALSE;
-cell = GAMGI_CAST_CELL direction->object.object;
+object = GAMGI_CAST_OBJECT direction->object.object;
+if (object->class != GAMGI_ENGINE_CELL) return FALSE;
+cell = GAMGI_CAST_CELL object;
+
 gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, pole);
 gamgi_math_cell_vector_rotate (cell, pole, normal2);
 
