@@ -106,6 +106,107 @@ gamgi_math_vector_cross (v1, v2, normal);
 gamgi_math_vector_normal (normal);
 }
 
+gamgi_bool gamgi_math_polygon_check_loops (int *loops,
+int n_loops, double *points, int n_points)
+{
+double center[3], radial[3], base[3], cross[3], cross_old[3];
+int n_faces, n_vertices, i, j;
+
+/**************************************
+ * check only objects with array data *
+ **************************************/
+
+if (n_loops == 0) return TRUE;
+
+/***************************
+ * check face construction *
+ ***************************/
+
+i = 0;
+n_faces = loops[i++];
+if (n_faces <= 0) return FALSE;
+
+while (n_faces-- > 0)
+  {
+  if (i >= n_loops) return FALSE;
+  n_vertices = loops[i++];
+  if (n_vertices <= 0) return FALSE;
+
+  /*******************
+   * get face center *
+   *******************/
+
+  gamgi_math_vector_zero (center);
+  for (j = i; j < i + n_vertices; j++)
+    {
+    if (j >= n_loops) return FALSE;
+    if (loops[j] >= n_points) return FALSE;
+    gamgi_math_vector_add (center, points + 3 * loops[j], center);
+    }
+  gamgi_math_vector_scale (center, center, 1.0 / n_vertices);
+
+  /*********************************************************************
+   * check face contour: cross vectors must point all to the same side *
+   *********************************************************************/
+
+  j = i + n_vertices - 1;
+  if (j >= n_loops) return FALSE;
+  gamgi_math_vector_sub (points + 3 * loops[j], center, base);
+  gamgi_math_vector_sub (points + 3 * loops[i], center, radial);
+  gamgi_math_vector_cross (base, radial, cross_old);
+  for (j = i; j < i + n_vertices; j++)
+    {
+    gamgi_math_vector_sub (points + 3 * loops[j], center, radial);
+    gamgi_math_vector_cross (base, radial, cross);
+    if (gamgi_math_vector_dot (cross, cross_old)
+    < -GAMGI_MATH_TOLERANCE_DOT) return FALSE;
+
+    gamgi_math_vector_copy (cross, cross_old);
+    gamgi_math_vector_copy (radial, base);
+    }
+  i += n_vertices;
+  }
+
+return TRUE;
+}
+
+gamgi_bool gamgi_math_polygon_check_colors (int *loops,
+int n_loops, float *colors, int n_colors, int *paints, int n_paints)
+{
+int n_faces, i;
+
+/**************************************
+ * check only objects with array data *
+ **************************************/
+
+if (n_loops == 0) return TRUE;
+
+/**********************************
+ * check array size compatibility *
+ **********************************/
+
+n_faces = loops[0];
+if (n_colors < 1 || n_colors > n_faces) return FALSE;
+if (n_paints != n_colors + 1) return FALSE;
+
+/**********************
+ * check colors array *
+ **********************/
+
+for (i = 0; i < 3 * n_colors; i++)
+  if (colors[i] < 0.0 || colors[i] > 1.0) return FALSE;
+
+/**********************
+ * check paints array *
+ **********************/
+
+for (i = 0; i < n_colors; i++)
+  if (paints[i] <= 0 || paints[0] >= n_loops) return FALSE;
+if (paints[n_colors] != 0) return FALSE;
+
+return TRUE;
+}
+
 double gamgi_math_polygon_area (int n_points, double *points)
 {
 double center[3], base[3], radial[3], normal[3];
@@ -144,6 +245,82 @@ for (n = 0; n < n_points; n++)
 return area / 2.0;
 }
 
+double gamgi_math_polygon_area_faces (int *faces, double *points)
+{
+double center[3], radial[3], base[3], cross[3];
+double area;
+int n_faces, n_vertices, i, j;
+
+i = 0;
+n_faces = faces[i++];
+
+/***************************************************************
+ * measure the accumulated area of the various faces (surface) *
+ ***************************************************************/
+
+area = 0.0;
+while (n_faces-- > 0)
+  {
+  n_vertices = faces[i++];
+
+  /*******************
+   * get face center *
+   *******************/
+
+  gamgi_math_vector_zero (center);
+  for (j = i; j < i + n_vertices; j++)
+    gamgi_math_vector_add (center, points + 3 * faces[j], center);
+  gamgi_math_vector_scale (center, center, 1.0 / n_vertices);
+
+  /*****************
+   * get face area *
+   *****************/
+
+  j = i + n_vertices - 1;
+  gamgi_math_vector_sub (points + 3 * faces[j], center, base);
+  for (j = i; j < i + n_vertices; j++)
+    {
+    gamgi_math_vector_sub (points + 3 * faces[j], center, radial);
+    gamgi_math_vector_cross (base, radial, cross);
+    area += gamgi_math_vector_length (cross);
+
+    gamgi_math_vector_copy (radial, base);
+    }
+
+  i += n_vertices;
+  }
+
+area /= 2.0;
+
+return area;
+}
+
+double gamgi_math_polygon_length_lines (int *lines, double *points)
+{
+double sub[3];
+double length;
+int vertex1, vertex2;
+int i, n_lines;
+
+/*******************************************************************
+ * measure the accumulated length of the various lines (perimeter) *
+ *******************************************************************/
+
+i = 0;
+n_lines = lines[i++];
+
+length = 0.0;
+while (n_lines-- > 0)
+  {
+  vertex1 = 3 * lines[i++];
+  vertex2 = 3 * lines[i++];
+  gamgi_math_vector_sub (points + vertex1, points + vertex2, sub);
+  length += gamgi_math_vector_length (sub);
+  }
+
+return length;
+}
+
 void gamgi_math_polygon_lines (int n_points, int **lines, int *n_lines)
 {
 int *array;
