@@ -362,7 +362,7 @@ if (class == GAMGI_ENGINE_DIRECTION)
 
 glPushMatrix ();
 
-if (direction->autonomy != GAMGI_GTK_NONE)
+if (direction->type == GAMGI_PHYS_LINE)
   {
   glTranslatef (direction->center[0], direction->center[1], direction->center[2]);
   glScalef (direction->object.scale, direction->object.scale, direction->object.scale);
@@ -385,15 +385,13 @@ if (direction->type == GAMGI_PHYS_LINE)
 
 else if (direction->type == GAMGI_PHYS_POLE)
   {
-  glPointSize (4.0);
   gamgi_mesa_render_points_chess (direction->loops[0],
-  direction->points, GAMGI_MESA_PLANE_WIDTH);
-  glPointSize (1.0);
+  direction->points, GAMGI_MESA_POLE_WIDTH * direction->object.scale);
   }
 
 else if (direction->type == GAMGI_PHYS_TRACE)
   {
-  glLineWidth (1.0);
+  glLineWidth (GAMGI_MESA_TRACE_WIDTH * direction->object.scale);
   gamgi_mesa_render_line_strip (direction->loops[0], direction->points);
   glLineWidth (1.0);
   }
@@ -441,7 +439,7 @@ if (class == GAMGI_ENGINE_PLANE)
 
 glPushMatrix ();
 
-if (plane->autonomy != GAMGI_GTK_NONE)
+if (plane->type == GAMGI_PHYS_POLYGON)
   {
   glTranslatef (plane->center[0], plane->center[1], plane->center[2]);
   glScalef (plane->object.scale, plane->object.scale, plane->object.scale);
@@ -450,7 +448,12 @@ if (plane->autonomy != GAMGI_GTK_NONE)
 
 glPushMatrix ();
 
-if (plane->reciprocal == 0.0)
+if (plane->type == GAMGI_PHYS_VECTOR)
+  {
+  gamgi_mesa_render_points_cross (plane->loops[0],
+  plane->origin, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
+  }
+else
   {
   glTranslatef (plane->origin[0], plane->origin[1], plane->origin[2]);
 
@@ -461,34 +464,24 @@ if (plane->reciprocal == 0.0)
 
     glDisable(GL_CULL_FACE);
     glEnable (GL_POLYGON_OFFSET_FILL);
-    glPolygonOffset (2, 2);
-
+    glPolygonOffset (1, 1);
     gamgi_mesa_render_polygons (plane->loops, plane->points);
-
     glDisable (GL_POLYGON_OFFSET_FILL);
     glEnable(GL_CULL_FACE);
     }
 
   else if (plane->type == GAMGI_PHYS_POLE)
     {
-    glPointSize (4.0);
     gamgi_mesa_render_points_cross (plane->loops[0],
-    plane->points, GAMGI_MESA_PLANE_WIDTH);
-    glPointSize (1.0);
+    plane->points, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
     }
 
   else if (plane->type == GAMGI_PHYS_TRACE)
     {
-    glLineWidth (1.0);
+    glLineWidth (GAMGI_MESA_TRACE_WIDTH * plane->object.scale);
     gamgi_mesa_render_line_strip (plane->loops[0], plane->points);
     glLineWidth (1.0);
     }
-
-  }
-else
-  {
-  gamgi_mesa_render_points_cross (plane->loops[0],
-  plane->origin, GAMGI_MESA_PLANE_WIDTH);
   }
 
 glPopMatrix ();
@@ -874,7 +867,7 @@ glPointSize (GAMGI_MESA_CELL_WIDTH);
 if (cell->faces == TRUE)
   {
   glEnable (GL_POLYGON_OFFSET_FILL);
-  glPolygonOffset (1, 1);
+  glPolygonOffset (2, 2);
 
   glPolygonMode (GL_FRONT, GL_FILL);
   glDisable(GL_CULL_FACE);
