@@ -22,6 +22,7 @@
 #include "gamgi_math_matrix.h"
 #include "gamgi_math_quaternion.h"
 #include "gamgi_mesa_draw.h"
+#include "gamgi_global_selection.h"
 
 static void static_center (gamgi_object *object, double *center)
 {
@@ -63,6 +64,11 @@ double angle, double *axis, double *quaternion, double *rotate)
 {
 gamgi_layer *layer;
 
+/********************************************************************
+ * quaternion, rotate must be recalculated only when layer changes, *
+ * as angle, axis remain the same throughout the rotation operation *
+ ********************************************************************/
+
 layer = gamgi_engine_find_layer (object);
 if (layer != *layer_old)
   {
@@ -657,14 +663,22 @@ gamgi_dlist *dlist;
 double rotate[9];
 double quaternion[4];
 
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_text (GAMGI_CAST_TEXT dlist->data, TRUE);
+
 for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
   {
   text = GAMGI_CAST_TEXT dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT text,
-  &layer, angle, axis, quaternion, rotate);
-  gamgi_mesa_rotate_text (text, quaternion, rotate, text->center);
+  if (text->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT text,
+    &layer, angle, axis, quaternion, rotate);
+    gamgi_mesa_rotate_text (text, quaternion, rotate, text->center);
+    }
   }
+
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_text (GAMGI_CAST_TEXT dlist->data, FALSE);
 }
 
 void gamgi_mesa_rotate_orbital_list (double angle, double *axis)
@@ -774,14 +788,22 @@ gamgi_dlist *dlist;
 double rotate[9];
 double quaternion[4];
 
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_group (GAMGI_CAST_GROUP dlist->data, TRUE);
+
 for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
   {
   group = GAMGI_CAST_GROUP dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT group,
-  &layer, angle, axis, quaternion, rotate);
-  gamgi_mesa_rotate_group (group, quaternion, rotate, group->center);
+  if (group->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT group,
+    &layer, angle, axis, quaternion, rotate);
+    gamgi_mesa_rotate_group (group, quaternion, rotate, group->center);
+    }
   }
+
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_group (GAMGI_CAST_GROUP dlist->data, FALSE);
 }
 
 void gamgi_mesa_rotate_molecule_list (double angle, double *axis)
@@ -810,14 +832,22 @@ gamgi_dlist *dlist;
 double rotate[9];
 double quaternion[4];
 
+for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_cluster (GAMGI_CAST_CLUSTER dlist->data, TRUE);
+
 for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
   {
   cluster = GAMGI_CAST_CLUSTER dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT cluster,
-  &layer, angle, axis, quaternion, rotate);
-  gamgi_mesa_rotate_cluster (cluster, quaternion, rotate, cluster->center);
+  if (cluster->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT cluster,
+    &layer, angle, axis, quaternion, rotate);
+    gamgi_mesa_rotate_cluster (cluster, quaternion, rotate, cluster->center);
+    }
   }
+
+for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_cluster (GAMGI_CAST_CLUSTER dlist->data, FALSE);
 }
 
 void gamgi_mesa_rotate_cell_list (double angle, double *axis)
@@ -906,14 +936,22 @@ gamgi_dlist *dlist;
 double rotate[9];
 double quaternion[4];
 
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_assembly (GAMGI_CAST_ASSEMBLY dlist->data, TRUE);
+
 for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
   {
   assembly = GAMGI_CAST_ASSEMBLY dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT assembly,
-  &layer, angle, axis, quaternion, rotate);
-  gamgi_mesa_rotate_assembly (assembly, quaternion, rotate, assembly->center);
+  if (assembly->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT assembly,
+    &layer, angle, axis, quaternion, rotate);
+    gamgi_mesa_rotate_assembly (assembly, quaternion, rotate, assembly->center);
+    }
   }
+
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_assembly (GAMGI_CAST_ASSEMBLY dlist->data, FALSE);
 }
 
 void gamgi_mesa_rotate_light_list (double angle, double *axis)
