@@ -393,15 +393,17 @@ number = 0;
 gamgi_engine_count_window (window, class, &number);
 if (number == 0) return NULL;
 
-/*******************************************************
- * allocate array to store candidate objects addresses *
- *******************************************************/
+/****************************************************************
+ * 1) allocate array to store candidate objects addresses       *
+ * 2) allocate array to store candidate objects scanning levels *
+ ****************************************************************/
 
 objects = (gamgi_object **) malloc (number * sizeof (object));
 if (objects == NULL) return NULL;
 
-levels = (int *) calloc (number, sizeof (int));
+levels = (int *) malloc (number * sizeof (int));
 if (levels == NULL) return NULL;
+for (level = 0; level < number; level++) levels[level] = 0;
 
 /***********************************************
  * render objects sucessively until no more    *
