@@ -154,12 +154,7 @@ plane->blue = plane_class->blue;
 void gamgi_mesa_start_group (gamgi_group *group, gamgi_group_class *group_class)
 {
 strcpy (group->object.name, "Group");
-
-group->structure = GAMGI_CHEM_STRUCTURE;
 group->type = GAMGI_CHEM_CONTAINER;
-group->filter = GAMGI_CHEM_FILTER;
-group->visible = GAMGI_CHEM_POLYTOPE_VISIBLE;
-group->coplanar = GAMGI_CHEM_POLYTOPE_COPLANAR;
 
 group->red = GAMGI_MESA_GROUP_R;
 group->green = GAMGI_MESA_GROUP_G;
