@@ -32,7 +32,7 @@ enum { GAMGI_PHYS_CONVENTIONAL = 1, GAMGI_PHYS_PRIMITIVE, GAMGI_PHYS_WIGNER,
 GAMGI_PHYS_PARALLELEPIPED, GAMGI_PHYS_SPHERE, GAMGI_PHYS_PROJECTION };
 
 enum { GAMGI_PHYS_POLE = 1, GAMGI_PHYS_TRACE, GAMGI_PHYS_POLYGON,
-GAMGI_PHYS_LINE, GAMGI_PHYS_RECIPROCAL };
+GAMGI_PHYS_LINE, GAMGI_PHYS_VECTOR };
 
 enum { GAMGI_PHYS_ALL = 1, GAMGI_PHYS_FACES, GAMGI_PHYS_EDGES, 
 GAMGI_PHYS_NONE };
