@@ -1737,7 +1737,7 @@ cell->o1, cell->o2, cell->o3, &o1, &o2, &o3, &o4);
 range[0] = 0; range[1] = n1 - 1;
 range[2] = 0; range[3] = n2 - 1;
 range[4] = 0; range[5] = 2 * n3 - 1;
-if (o4 == GAMGI_PHYS_NODE_122) { range[4] -= 1; range[5] -= 1; }
+if (o4 == GAMGI_PHYS_122) { range[4] -= 1; range[5] -= 1; }
 
 /***********************************
  * this unneeded initialization    *
