@@ -227,7 +227,7 @@ gamgi_math_vector_scale (direction->center, direction->center, 0.5);
 }
 
 static gamgi_darray *static_line (gamgi_direction *direction,
-double *position, double *normal, gamgi_dlist *dlist)
+double thickness, double *position, double *normal, gamgi_dlist *dlist)
 {
 gamgi_atom *atom;
 gamgi_darray *darray;
@@ -257,7 +257,7 @@ while (dlist != NULL)
   gamgi_math_vector_sub (point, r, point);
   length = gamgi_math_vector_length (point);
 
-  if (fabs (length) < direction->thickness)
+  if (fabs (length) < thickness)
     {
     gamgi_math_vector_sub (atom->position, point, point);
     gamgi_engine_darray_push (darray, point);
@@ -270,7 +270,7 @@ return darray;
 }
 
 static void static_copy (gamgi_direction *direction,
-double *normal, gamgi_dlist *start)
+double thickness, double *normal, gamgi_dlist *start)
 {
 gamgi_atom *atom, *atom_new;
 gamgi_dlist *dlist;
@@ -292,7 +292,7 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_math_vector_sub (r, s, r);
   length = gamgi_math_vector_length (r);
 
-  if (fabs (length) < direction->thickness)
+  if (fabs (length) < thickness)
     {
     atom_new = gamgi_engine_copy_atom (atom);
     gamgi_engine_link_atom_direction (atom_new, direction);
@@ -307,8 +307,8 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
 }
 
-static void static_link (gamgi_direction *direction, double *normal,
-gamgi_dlist *start)
+static void static_link (gamgi_direction *direction,
+double thickness, double *normal, gamgi_dlist *start)
 {
 gamgi_atom *atom;
 gamgi_dlist *dlist;
@@ -330,7 +330,7 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_math_vector_sub (r, s, r);
   length = gamgi_math_vector_length (r);
 
-  if (fabs (length) < direction->thickness)
+  if (fabs (length) < thickness)
     {
     gamgi_engine_unlink_atom (atom);
     gamgi_engine_link_atom_direction (atom, direction);
@@ -382,9 +382,9 @@ gamgi_engine_remove_plane (plane);
 return order - step;
 }
 
-static gamgi_bool static_range (gamgi_direction *direction, 
-gamgi_cell *cell, int *node, int *swap, double *normal, 
-gamgi_bool link, gamgi_dlist *dlist)
+static gamgi_bool static_range (gamgi_direction *direction, gamgi_cell *cell,
+gamgi_enum structure, double thickness, gamgi_dlist *dlist, int *node, int *swap,
+double *normal, gamgi_bool link)
 {
 gamgi_direction *direction_new;
 int node_p[3];
@@ -436,10 +436,10 @@ inside = gamgi_phys_direction_cell (direction_new, cell);
 if (inside == TRUE || link == TRUE)
   {
   gamgi_engine_link_direction_cell (direction_new, cell);
-  if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
-    static_copy (direction_new, normal, dlist);
-  if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
-    static_link (direction_new, normal, dlist);
+  if (structure == GAMGI_CHEM_STRUCTURE_COPY)
+    static_copy (direction_new, thickness, normal, dlist);
+  if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+    static_link (direction_new, thickness, normal, dlist);
   }
 else gamgi_engine_remove_direction (direction_new);
 
@@ -946,8 +946,9 @@ while (dlist != NULL)
 return start;
 }
 
-void gamgi_phys_direction_atoms (gamgi_direction *direction,
-gamgi_atom *atom1, gamgi_atom *atom2, gamgi_dlist *dlist, gamgi_bool copy)
+void gamgi_phys_direction_atoms (gamgi_direction *direction, gamgi_atom *atom1,
+gamgi_atom *atom2, gamgi_dlist *dlist, gamgi_enum structure, double thickness,
+gamgi_bool copy)
 {
 gamgi_darray *darray;
 double unit[9], rotation[9];
@@ -989,7 +990,7 @@ gamgi_math_position_object_translation (direction->object.object, zero);
 gamgi_math_vector_sub (atom2->position, atom1->position, normal);
 gamgi_math_vector_normal (normal);
 
-darray = static_line (direction, atom1->position, normal, dlist);
+darray = static_line (direction, thickness, atom1->position, normal, dlist);
 static_segment (darray);
 
 /***************************
@@ -1007,10 +1008,10 @@ static_center (direction);
  * link or copy atoms to direction *
  ***********************************/
 
-if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
-  static_copy (direction, normal, dlist);
-if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
-  static_link (direction, normal, dlist);
+if (structure == GAMGI_CHEM_STRUCTURE_COPY)
+  static_copy (direction, thickness, normal, dlist);
+if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (direction, thickness, normal, dlist);
 
 /*******************************************
  * rotate the parent object, including     *
@@ -1049,7 +1050,6 @@ strcpy (direction->object.name, "Direction");
 
 direction->reference = GAMGI_ENGINE_ATOM;
 direction->type = GAMGI_PHYS_LINE;
-direction->thickness = GAMGI_CHEM_DIRECTION_THICKNESS;
 
 direction->red = red;
 direction->green = green;
@@ -1162,11 +1162,10 @@ gamgi_math_position_object_rotation (direction->object.object, rotation);
 gamgi_math_position_object_translation (direction->object.object, translation);
 }
 
-void gamgi_phys_direction_range (gamgi_direction *direction,
-gamgi_cell *cell, int *hkl1, int start1, int end1, int *hkl2,
-int start2, int end2)
+void gamgi_phys_direction_range (gamgi_direction *direction, gamgi_cell *cell,
+gamgi_enum structure, gamgi_enum filter, double thickness, gamgi_dlist *dlist,
+int *hkl1, int start1, int end1, int *hkl2, int start2, int end2)
 {
-gamgi_dlist *dlist = NULL;
 double rotate[9];
 double vector[3], normal[3];
 int swap[3];
@@ -1187,10 +1186,6 @@ gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
 gamgi_math_matrix_vector (rotate, vector, normal);
 gamgi_math_vector_normal (normal);
 
-dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-dlist = gamgi_engine_filter_atom (dlist, direction->filter,
-GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
-
 /*******************************************
  * convert plane indices to primitive axes *
  *******************************************/
@@ -1255,24 +1250,16 @@ for (i = start1; i <= end1; i++)
   for (j = start2; j <= end2; j++)
     {
     if (gamgi_math_diophantine_intersect (hkl1_s, hkl2_s, i, j, node) == TRUE)
-      static_range (direction, cell, node, swap, normal, link, dlist);
+      static_range (direction, cell, structure,
+      thickness, dlist, node, swap, normal, link);
     }
   }
-
-/***************************
- * free list of atoms      *
- * free original direction *
- ***************************/
-
-while (dlist != NULL)
-  dlist = gamgi_engine_dlist_remove_start (dlist);
-
-gamgi_engine_remove_direction (direction);
 }
 
-void gamgi_phys_direction_node (gamgi_direction *direction, gamgi_cell *cell)
+void gamgi_phys_direction_node (gamgi_direction *direction, gamgi_cell *cell,
+gamgi_enum structure, gamgi_enum filter, double thickness, gamgi_dlist *dlist)
 {
-gamgi_dlist *dlist = NULL;
+gamgi_direction *direction_new;
 double rotate[9];
 double vector[3], normal[3];
 
@@ -1282,11 +1269,12 @@ double vector[3], normal[3];
  * rotated according to the cell orientation *
  *********************************************/
 
-gamgi_phys_direction_cell (direction, cell);
-gamgi_engine_link_direction_cell (direction, cell);
+direction_new = gamgi_engine_copy_direction (direction);
+gamgi_phys_direction_cell (direction_new, cell);
+gamgi_engine_link_direction_cell (direction_new, cell);
 
 gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
-gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
+gamgi_phys_direction_vector (cell, direction_new->uvw, direction_new->vectors, vector);
 gamgi_math_matrix_vector (rotate, vector, normal);
 gamgi_math_vector_normal (normal);
 
@@ -1295,32 +1283,16 @@ gamgi_math_vector_normal (normal);
  * 2) apply structure policy; 3) free atom list. *
  *************************************************/
 
-dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-dlist = gamgi_engine_filter_atom (dlist, direction->filter,
-GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
-
-if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
-  static_copy (direction, normal, dlist);
-if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
-  static_link (direction, normal, dlist);
-
-while (dlist != NULL)
-  dlist = gamgi_engine_dlist_remove_start (dlist);
+if (structure == GAMGI_CHEM_STRUCTURE_COPY)
+  static_copy (direction_new, thickness, normal, dlist);
+if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (direction_new, thickness, normal, dlist);
 }
 
 void gamgi_phys_direction_projection (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
-gamgi_direction *direction_pole = NULL;
-gamgi_direction *direction_trace = NULL;
-
-if (pole == TRUE && trace == TRUE)
-  {
-  direction_pole = direction;
-  direction_trace = gamgi_engine_copy_direction (direction);
-  }
-else if (pole == TRUE) direction_pole = direction;
-else if (trace == TRUE) direction_trace = direction;
+gamgi_direction *direction_new;
 
 if (pole == TRUE)
   {
@@ -1330,15 +1302,15 @@ if (pole == TRUE)
    * link direction to cell before building pole *
    ***********************************************/
 
-  direction_pole->type = GAMGI_PHYS_POLE;
-  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &direction_pole->points,
-  &direction_pole->n_points, &direction_pole->loops, &direction_pole->n_loops);
+  direction_new = gamgi_engine_copy_direction (direction);
+  direction_new->type = GAMGI_PHYS_POLE;
+  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &direction_new->points,
+  &direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
 
-  gamgi_engine_link_direction_cell (direction_pole, cell);
-  gamgi_mesa_rotate_out_direction (direction_pole, NULL, NULL, NULL);
+  gamgi_engine_link_direction_cell (direction_new, cell);
+  gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
   }
 
-
 if (trace == TRUE)
   {
   /************************************************
@@ -1347,12 +1319,13 @@ if (trace == TRUE)
    * link direction to cell before building trace *
    ************************************************/
 
-  direction_trace->type = GAMGI_PHYS_TRACE;
-  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &direction_trace->points,
-  &direction_trace->n_points, &direction_trace->loops, &direction_trace->n_loops);
+  direction_new = gamgi_engine_copy_direction (direction);
+  direction_new->type = GAMGI_PHYS_TRACE;
+  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &direction_new->points,
+  &direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
 
-  gamgi_engine_link_direction_cell (direction_trace, cell);
-  gamgi_mesa_rotate_out_direction (direction_trace, NULL, NULL, NULL);
+  gamgi_engine_link_direction_cell (direction_new, cell);
+  gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
   }
 
 }
