@@ -814,7 +814,7 @@ gamgi_math_vector_scale (plane->center, plane->center, 1.0 / plane->n_points);
 }
 
 static gamgi_darray *static_polygon_dlist (gamgi_plane *plane,
-double *position, double *normal, gamgi_dlist *dlist)
+double thickness, double *position, double *normal, gamgi_dlist *dlist)
 {
 gamgi_atom *atom;
 gamgi_darray *darray;
@@ -841,7 +841,7 @@ while (dlist != NULL)
   gamgi_math_vector_sub (atom->position, position, point);
   length = gamgi_math_vector_dot (point, normal);
 
-  if (fabs (length) < plane->thickness)
+  if (fabs (length) < thickness)
     {
     /**********************************
      * add projected point to polygon *
@@ -890,8 +890,8 @@ for (i = 0; i < n_neighbours; i++)
 return darray;
 }
 
-static void static_copy (gamgi_plane *plane, double *normal,
-gamgi_dlist *start)
+static void static_copy (gamgi_plane *plane, double thickness,
+gamgi_dlist *start, double *normal)
 {
 gamgi_atom *atom, *atom_new;
 gamgi_dlist *dlist;
@@ -910,7 +910,7 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_math_vector_sub (atom->position, plane->center, r);
   length = gamgi_math_vector_dot (r, normal);
 
-  if (fabs (length) < plane->thickness)
+  if (fabs (length) < thickness)
     {
     atom_new = gamgi_engine_copy_atom (atom);
     gamgi_engine_link_atom_plane (atom_new, plane);
@@ -925,8 +925,8 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
 }
 
-static void static_link (gamgi_plane *plane, double *normal,
-gamgi_dlist *start)
+static void static_link (gamgi_plane *plane, double thickness,
+gamgi_dlist *start, double *normal)
 {
 gamgi_atom *atom;
 gamgi_dlist *dlist;
@@ -945,7 +945,7 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_math_vector_sub (atom->position, plane->center, r);
   length = gamgi_math_vector_dot (r, normal);
 
-  if (fabs (length) < plane->thickness)
+  if (fabs (length) < thickness)
     {
     gamgi_engine_unlink_atom (atom);
     gamgi_engine_link_atom_plane (atom, plane);
@@ -989,8 +989,9 @@ gamgi_math_vector_scale (normal, normal, 1/length);
 return TRUE;
 }
 
-static gamgi_bool static_range (gamgi_plane *plane, int order, 
-double *normal, gamgi_cell *cell, gamgi_bool link, gamgi_dlist *dlist)
+static gamgi_bool static_range (gamgi_plane *plane, gamgi_cell *cell,
+gamgi_enum structure, double thickness, gamgi_dlist *dlist, int order,
+double *normal, gamgi_bool link)
 {
 gamgi_plane *plane_new;
 gamgi_bool inside;
@@ -1015,10 +1016,10 @@ inside = gamgi_phys_plane_cell (plane_new, cell);
 if (inside == TRUE || link == TRUE)
   {
   gamgi_engine_link_plane_cell (plane_new, cell);
-  if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
-    static_copy (plane_new, normal, dlist);
-  if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
-    static_link (plane_new, normal, dlist);
+  if (structure == GAMGI_CHEM_STRUCTURE_COPY)
+    static_copy (plane_new, thickness, dlist, normal);
+  if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+    static_link (plane_new, thickness, dlist, normal);
   }
 else gamgi_engine_remove_plane (plane_new);
 
@@ -1030,74 +1031,6 @@ else gamgi_engine_remove_plane (plane_new);
 return inside;
 }
 
-static void static_multiple (gamgi_plane *plane, gamgi_cell *cell, 
-int start, int end, gamgi_dlist *dlist, double *normal)
-{
-int order, n;
-
-/**************************************************************
- * show all planes inside: 1) get order of plane passing      *
- * through the cell origin (0, if the origin did not change); *
- * 2) scan all planes in both directions, from the origin     *
- **************************************************************/
-
-if (start == -INT_MAX && end == INT_MAX)
-  {
-  order = -gamgi_phys_plane_order (cell, plane->hkl, 
-  plane->vectors, cell->o1, cell->o2, cell->o3);
-  static_range (plane, order, normal, cell, FALSE, dlist);
-
-  for (n = order + 1; n < INT_MAX; n++)
-    if (static_range (plane, n, normal, 
-    cell, FALSE, dlist) == FALSE) break;
-
-  for (n = order - 1; n > -INT_MAX; n--)
-    if (static_range (plane, n, normal, 
-    cell, FALSE, dlist) == FALSE) break;
-  }
-
-/**************************************
- * show start, even if it is outside, *
- * plus all planes inside from start  *
- **************************************/
-
-else if (end == INT_MAX)
-  {
-  static_range (plane, start, normal, cell, TRUE, dlist);
-
-  for (n = start + 1; n < INT_MAX; n++)
-    if (static_range (plane, n, normal, 
-    cell, FALSE, dlist) == FALSE) break;
-  }
-
-/*************************************
- * show end, even if it is outside,  *
- * plus all planes inside until end  *
- *************************************/
-
-else if (start == -INT_MAX)
-  {
-  static_range (plane, end, normal, cell, TRUE, dlist);
-
-  for (n = end - 1; n > -INT_MAX; n--)
-    if (static_range (plane, n, normal, 
-    cell, FALSE, dlist) == FALSE) break;
-  }
-
-/*********************************
- * show all planes from start to *
- * end, even if they are outside *
- *********************************/
-
-else
-  {
-  for (n = start; n <= end; n++)
-    static_range (plane, n, normal, cell, TRUE, dlist);
-  }
-
-gamgi_engine_remove_plane (plane);
-}
-
 int gamgi_phys_plane_order (gamgi_cell *cell, 
 int *hkl, gamgi_enum vectors, int o1, int o2, int o3)
 {
@@ -1616,7 +1549,8 @@ return start;
 }
 
 void gamgi_phys_plane_atoms (gamgi_plane *plane, gamgi_atom *atom1, 
-gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist)
+gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist,
+gamgi_enum structure, double thickness)
 {
 gamgi_darray *darray;
 double unit[9], rotation[9];
@@ -1659,7 +1593,8 @@ gamgi_math_position_object_translation (plane->object.object, zero);
 gamgi_math_polygon_normal (atom1->position,
 atom2->position, atom3->position, normal);
 
-darray = static_polygon_dlist (plane, atom1->position, normal, dlist);
+darray = static_polygon_dlist (plane,
+thickness, atom1->position, normal, dlist);
 
 gamgi_math_polygon_orientate (darray, normal);
 gamgi_math_polygon_convex (darray, normal);
@@ -1681,10 +1616,10 @@ static_center (plane);
  * link,copy,none atoms to plane *
  *********************************/
 
-if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
-  static_copy (plane, normal, dlist);
-if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
-  static_link (plane, normal, dlist);
+if (structure == GAMGI_CHEM_STRUCTURE_COPY)
+  static_copy (plane, thickness, dlist, normal);
+if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (plane, thickness, dlist, normal);
 
 /***************************************
  * rotate the parent object, including *
@@ -1724,8 +1659,6 @@ strcpy (plane->object.name, "Plane");
 
 plane->reference = GAMGI_ENGINE_ATOM;
 plane->type = GAMGI_PHYS_POLYGON;
-plane->structure = structure;
-plane->thickness = GAMGI_CHEM_PLANE_THICKNESS;
 
 plane->red = red;
 plane->green = green;
@@ -1833,20 +1766,13 @@ gamgi_math_position_object_rotation (plane->object.object, rotation);
 gamgi_math_position_object_translation (plane->object.object, translation);
 }
 
-void gamgi_phys_plane_range (gamgi_plane *plane, 
-gamgi_cell *cell, int start, int end)
+void gamgi_phys_plane_range (gamgi_plane *plane, gamgi_cell *cell,
+gamgi_enum structure, gamgi_enum filter, double thickness,
+gamgi_dlist *dlist, int start, int end)
 {
-gamgi_dlist *dlist = NULL;
 double rotate[9];
 double vector[3], normal[3];
-
-/*******************************************
- * get list of atoms belonging to the cell *
- *******************************************/
-
-dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-dlist = gamgi_engine_filter_atom (dlist, plane->filter,
-GAMGI_ENGINE_PLANE, GAMGI_CAST_OBJECT cell);
+int order, n;
 
 /**************************************************************
  * get plane normal,rotated according to the cell orientation *
@@ -1861,41 +1787,76 @@ gamgi_math_vector_normal (normal);
  * build new planes, link to cell, apply structure policy *
  **********************************************************/
 
-if (start == end)
+/**************************************************************
+ * show all planes inside: 1) get order of plane passing      *
+ * through the cell origin (0, if the origin did not change); *
+ * 2) scan all planes in both directions, from the origin     *
+ **************************************************************/
+
+if (start == -INT_MAX && end == INT_MAX)
   {
-  plane->order = start;
-  gamgi_phys_plane_cell (plane, cell);
-  gamgi_engine_link_plane_cell (plane, cell);
+  order = -gamgi_phys_plane_order (cell, plane->hkl, 
+  plane->vectors, cell->o1, cell->o2, cell->o3);
+  static_range (plane, cell, structure,
+  thickness, dlist, order, normal, FALSE);
 
-  if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
-    static_copy (plane, normal, dlist);
-  if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
-    static_link (plane, normal, dlist);
+  for (n = order + 1; n < INT_MAX; n++)
+    if (static_range (plane, cell, structure, thickness,
+    dlist, n, normal, FALSE) == FALSE) break;
+
+  for (n = order - 1; n > -INT_MAX; n--)
+    if (static_range (plane, cell, structure, thickness,
+    dlist, n, normal, FALSE) == FALSE) break;
   }
-else static_multiple (plane, cell, start, end, dlist, normal);
 
-/******************
- * free atom list *
- ******************/
+/**************************************
+ * show start, even if it is outside, *
+ * plus all planes inside from start  *
+ **************************************/
 
-while (dlist != NULL)
-  dlist = gamgi_engine_dlist_remove_start (dlist);
+else if (end == INT_MAX)
+  {
+  static_range (plane, cell, structure,
+  thickness, dlist, start, normal, TRUE);
+
+  for (n = start + 1; n < INT_MAX; n++)
+    if (static_range (plane, cell, structure, thickness,
+    dlist, n, normal, FALSE) == FALSE) break;
+  }
+
+/*************************************
+ * show end, even if it is outside,  *
+ * plus all planes inside until end  *
+ *************************************/
+
+else if (start == -INT_MAX)
+  {
+  static_range (plane, cell, structure,
+  thickness, dlist, end, normal, TRUE);
+
+  for (n = end - 1; n > -INT_MAX; n--)
+    if (static_range (plane, cell, structure, thickness,
+    dlist, n, normal, FALSE) == FALSE) break;
+  }
+
+/*********************************
+ * show all planes from start to *
+ * end, even if they are outside *
+ *********************************/
+
+else
+  {
+  for (n = start; n <= end; n++)
+    static_range (plane, cell, structure,
+    thickness, dlist, n, normal, TRUE);
+  }
 }
 
 void gamgi_phys_plane_projection (gamgi_plane *plane,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
-gamgi_plane *plane_pole = NULL;
-gamgi_plane *plane_trace = NULL;
+gamgi_plane *plane_new;
 
-if (pole == TRUE && trace == TRUE)
-  {
-  plane_pole = plane;
-  plane_trace = gamgi_engine_copy_plane (plane);
-  }
-else if (pole == TRUE) plane_pole = plane;
-else if (trace == TRUE) plane_trace = plane;
-  
 if (pole == TRUE)
   {
   /*******************************************
@@ -1904,15 +1865,15 @@ if (pole == TRUE)
    * link plane to cell before building pole *
    *******************************************/
 
-  plane_pole->type = GAMGI_PHYS_POLE;
-  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &plane_pole->points,
-  &plane_pole->n_points, &plane_pole->loops, &plane_pole->n_loops);
+  plane_new = gamgi_engine_copy_plane (plane);
+  plane_new->type = GAMGI_PHYS_POLE;
+  gamgi_phys_projection_create (GAMGI_PHYS_POLE, &plane_new->points,
+  &plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
 
-  gamgi_engine_link_plane_cell (plane_pole, cell);
-  gamgi_mesa_rotate_out_plane (plane_pole, NULL, NULL, NULL);
+  gamgi_engine_link_plane_cell (plane_new, cell);
+  gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
   }
 
-
 if (trace == TRUE)
   {
   /********************************************
@@ -1921,12 +1882,13 @@ if (trace == TRUE)
    * link plane to cell before building trace *
    ********************************************/
 
-  plane_trace->type = GAMGI_PHYS_TRACE;
-  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &plane_trace->points,
-  &plane_trace->n_points, &plane_trace->loops, &plane_trace->n_loops);
+  plane_new = gamgi_engine_copy_plane (plane);
+  plane_new->type = GAMGI_PHYS_TRACE;
+  gamgi_phys_projection_create (GAMGI_PHYS_TRACE, &plane_new->points,
+  &plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
 
-  gamgi_engine_link_plane_cell (plane_trace, cell);
-  gamgi_mesa_rotate_out_plane (plane_trace, NULL, NULL, NULL);
+  gamgi_engine_link_plane_cell (plane_new, cell);
+  gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
   }
 
 }
