@@ -49,22 +49,23 @@ double *r2, double *r3);
 
 static void static_center (gamgi_plane *plane);
 
-static gamgi_darray *static_polygon (gamgi_plane *plane,
-double *position, double *normal, gamgi_dlist *dlist);
+static gamgi_darray *static_polygon_dlist (gamgi_plane *plane,
+double thickness, double *position, double *normal, gamgi_dlist *dlist);
 
-static void static_copy (gamgi_plane *plane, double *normal,
-gamgi_dlist *start);
+static gamgi_darray *static_polygon_array (gamgi_plane *plane,
+int n_neighbours, gamgi_atom **neighbours);
 
-static void static_link (gamgi_plane *plane, double *normal,
-gamgi_dlist *start);
+static void static_copy (gamgi_plane *plane, double thickness,
+gamgi_dlist *start, double *normal);
+
+static void static_link (gamgi_plane *plane, double thickness,
+gamgi_dlist *start, double *normal);
 
 static gamgi_bool static_normal (gamgi_plane *plane, double *normal);
 
-static gamgi_bool static_range (gamgi_plane *plane, int order,
-double *normal, gamgi_cell *cell, gamgi_bool link, gamgi_dlist *dlist);
-
-static void static_multiple (gamgi_plane *plane, gamgi_cell *cell,
-int start, int end, gamgi_dlist *dlist, double *normal);
+static gamgi_bool static_range (gamgi_plane *plane, gamgi_cell *cell,
+gamgi_enum structure, double thickness, gamgi_dlist *dlist, int order,
+double *normal, gamgi_bool link);
 
  **********************
  * external functions *
@@ -114,14 +115,16 @@ gamgi_dlist *gamgi_phys_plane_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2, gamgi_atom *atom3);
 
 void gamgi_phys_plane_atoms (gamgi_plane *plane, gamgi_atom *atom1,
-gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist);
+gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist,
+gamgi_enum structure, double thickness);
 
 void gamgi_phys_plane_polytope (int n_neighbours, gamgi_atom **neighbours,
 gamgi_enum structure, float red, float green, float blue, gamgi_object *parent,
 gamgi_atom *central);
 
-void gamgi_phys_plane_range (gamgi_plane *plane,
-gamgi_cell *cell, int start, int end);
+void gamgi_phys_plane_range (gamgi_plane *plane, gamgi_cell *cell,
+gamgi_enum structure, gamgi_enum filter, double thickness,
+gamgi_dlist *dlist, int start, int end);
 
 void gamgi_phys_plane_projection (gamgi_plane *plane,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace);
